import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { Partners } from './schema/partners.schema';
import { PartnersRepository } from './partners.repository';
import { CreatePartnersDto } from './dto/create-partners.dto';
import { UpdatePartnersDto } from './dto/update-clients.dto';



@Injectable()
export class PartnersService {
    constructor(private readonly doSpaceService: DoSpacesService,
        @InjectModel('partners') private readonly partnersModel: Model<Partners>) { }

    private readonly partnersRepository = new PartnersRepository(this.partnersModel);

    async create(dto: CreatePartnersDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Partners> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Partners/");
            dto.image = img;
        }

        const data = await this.partnersRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to Partners.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<Partners[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.partnersRepository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<Partners | null> {
        const data = await this.partnersRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdatePartnersDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Partners | null> {
        const res = await this.partnersRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const foundImage = (res as Partners)?.image;
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Partners/");
            dto.image = img;
        } else {
            dto.image = foundImage;
        }

        const data = await this.partnersRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.partnersRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.partnersRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}