import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AnalyticsDashboardSectionFiveCms } from "./schema/analytics-dashboard-section-five-cms.schema";
import { AnalyticsDashboardSectionFiveCmsRepository } from "./analytics-dashboard-section-five-cms.repository";
import { UpdateAnalyticsDashboardSectionFiveCmsDto } from "./dto/update-analytics-dashboard-section-five-cms.dto";

@Injectable()
export class AnalyticsDashboardSectionFiveCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytics_dashboard_section_five_cms')
        private readonly analyticsDashboardSectionFiveCmsModel: Model<AnalyticsDashboardSectionFiveCms>
    ) { }

    private readonly analyticsDashboardSectionFiveCmsRepository =
        new AnalyticsDashboardSectionFiveCmsRepository(this.analyticsDashboardSectionFiveCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionFiveCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<AnalyticsDashboardSectionFiveCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "AnalyticsDashboardSectionFiveCms/");
            dto.image = img;
        }
        const isExists = await this.analyticsDashboardSectionFiveCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionFiveCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionFiveCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionFiveCms[] | Error> {
        const data = await this.analyticsDashboardSectionFiveCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}