import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AnalyticsDashboardSectionFourCmsRepository } from "./analytics-dashboard-section-four-cms.repository";
import { UpdateAnalyticsDashboardSectionFourCmsDto } from "./dto/update-analytics-dashboard-section-four-cms.dto";
import { AnalyticsDashboardSectionFourCms } from "./schema/analytics-dashboard-section-four-cms.schema";

@Injectable()
export class AnalyticsDashboardSectionFourCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytics_dashboard_section_four_cms')
        private readonly analyticsDashboardSectionFourCmsModel: Model<AnalyticsDashboardSectionFourCms>
    ) { }

    private readonly analyticsDashboardSectionFourCmsRepository =
        new AnalyticsDashboardSectionFourCmsRepository(this.analyticsDashboardSectionFourCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionFourCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<AnalyticsDashboardSectionFourCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "AnalyticsDashboardSectionFourCms/");
            dto.image = img;
        }
        const isExists = await this.analyticsDashboardSectionFourCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionFourCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionFourCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionFourCms[] | Error> {
        const data = await this.analyticsDashboardSectionFourCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}