import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AnalyticsDashboardSectionOneCms } from "./schema/analytics-dashboard-section-one-cms.schema";
import { AnalyticsDashboardSectionOneCmsRepository } from "./analytics-dashboard-section-one-cms.repository";
import { UpdateAnalyticsDashboardSectionOneCmsDto } from "./dto/update-analytics-dashboard-section-one-cms.dto";

@Injectable()
export class AnalyticsDashboardSectionOneCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytics_dashboard_section_one_cms')
        private readonly analyticsDashboardSectionOneCmsModel: Model<AnalyticsDashboardSectionOneCms>
    ) { }

    private readonly analyticsDashboardSectionOneCmsRepository =
        new AnalyticsDashboardSectionOneCmsRepository(this.analyticsDashboardSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionOneCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<AnalyticsDashboardSectionOneCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "AnalyticsDashboardSectionOneCms/");
            dto.image = img;
        }
        const isExists = await this.analyticsDashboardSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionOneCms[] | Error> {
        const data = await this.analyticsDashboardSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}