import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { AnalyticsDashboardSectionSixCms } from "./schema/analytics-dashboard-section-six-cms.schema";
import { AnalyticsDashboardSectionSixCmsRepository } from "./analytics-dashboard-section-six-cms.repository";
import { UpdateAnalyticsDashboardSectionSixCmsDto } from "./dto/update-analytics-dashboard-section-six-cms.dto";


@Injectable()
export class AnalyticsDashboardSectionSixCmsService {
    constructor(
        @InjectModel('analytics_dashboard_section_six_cms')
        private readonly analyticsDashboardSectionSixCmsModel: Model<AnalyticsDashboardSectionSixCms>
    ) { }

    private readonly analyticsDashboardSectionSixCmsRepository =
        new AnalyticsDashboardSectionSixCmsRepository(this.analyticsDashboardSectionSixCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionSixCmsDto
    ): Promise<AnalyticsDashboardSectionSixCms | Error> {
        const isExists = await this.analyticsDashboardSectionSixCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionSixCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionSixCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionSixCms[] | Error> {
        const data = await this.analyticsDashboardSectionSixCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}