import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { AnalyticsDashboardSectionSix } from './schema/analytics-dashboard-section-six.schema';
import { AnalyticsDashboardSectionSixRepository } from './analytics-dashboard-section-six.repository';
import { CreateAnalyticsDashboardSectionSixDto } from './dto/create-analytics-dashboard-section-six.dto';
import { UpdateUpdateAnalyticsDashboardSectionSixDto } from './dto/update-analytics-dashboard-section-six.dto';



@Injectable()
export class AnalyticsDashboardSectionSixService {
    constructor(private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytic_dashboard_section_six') private readonly analyticsDashboardSectionSixModel: Model<AnalyticsDashboardSectionSix>) { }

    private readonly analyticsDashboardSectionSixRepository = new AnalyticsDashboardSectionSixRepository(this.analyticsDashboardSectionSixModel);

    async create(dto: CreateAnalyticsDashboardSectionSixDto,
        files: {
            teamImage?: UploadedMulterFileI
        }): Promise<AnalyticsDashboardSectionSix> {
        if (files && files.teamImage) {
            const img: any = await this.doSpaceService.uploadFile(files.teamImage[0], "AnalyticsDashboardSectionSix/");
            dto.teamImage = img;
        }

        const data = await this.analyticsDashboardSectionSixRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to Analytics Dashboard Section Six.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<AnalyticsDashboardSectionSix[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.analyticsDashboardSectionSixRepository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<AnalyticsDashboardSectionSix | null> {
        const data = await this.analyticsDashboardSectionSixRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateUpdateAnalyticsDashboardSectionSixDto,
        files: {
            teamImage?: UploadedMulterFileI
        }): Promise<AnalyticsDashboardSectionSix | null> {
        const res = await this.analyticsDashboardSectionSixRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const foundImage = (res as AnalyticsDashboardSectionSix)?.teamImage;
        if (files && files.teamImage) {
            const img: any = await this.doSpaceService.uploadFile(files.teamImage[0], "AnalyticsDashboardSectionSix/");
            dto.teamImage = img;
        } else {
            dto.teamImage = foundImage;
        }

        const data = await this.analyticsDashboardSectionSixRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.analyticsDashboardSectionSixRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.analyticsDashboardSectionSixRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}