import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { Constants } from "src/utils/constants";
import { AnalyticsDashboardSectionThreeCmsService } from "./analytics-dashboard-section-three-cms.service";
import { UpdateAnalyticsDashboardSectionThreeCmsDto } from "./dto/update-analytics-dashboard-section-three-cms.dto";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";

@Controller({ path: "analytics-dashboard-section-three-cms", version: Constants.API_VERSION_1 })

export class AnalyticsDashboardSectionThreeCmsController {
    constructor(private readonly service: AnalyticsDashboardSectionThreeCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "cardOneIcon", maxCount: 1 },
            { name: "cardTwoIcon", maxCount: 1 },
            { name: "cardThreeIcon", maxCount: 1 },
            { name: "cardFourIcon", maxCount: 1 },
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateAnalyticsDashboardSectionThreeCmsDto,
        @UploadedFiles() files: {
            cardOneIcon?: UploadedMulterFileI,
            cardTwoIcon?: UploadedMulterFileI,
            cardThreeIcon?: UploadedMulterFileI,
            cardFourIcon?: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto,files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
