import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AnalyticsDashboardSectionThreeCms } from "./schema/analytics-dashboard-section-three-cms.schema";
import { AnalyticsDashboardSectionThreeCmsRepository } from "./analytics-dashboard-section-three-cms.repository";
import { UpdateAnalyticsDashboardSectionThreeCmsDto } from "./dto/update-analytics-dashboard-section-three-cms.dto";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";

@Injectable()
export class AnalyticsDashboardSectionThreeCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytics_dashboard_section_three_cms')
        private readonly analyticsDashboardSectionThreeCmsModel: Model<AnalyticsDashboardSectionThreeCms>
    ) { }

    private readonly analyticsDashboardSectionThreeCmsRepository =
        new AnalyticsDashboardSectionThreeCmsRepository(this.analyticsDashboardSectionThreeCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionThreeCmsDto,
        files: {
            cardOneIcon?: UploadedMulterFileI,
            cardTwoIcon?: UploadedMulterFileI,
            cardThreeIcon?: UploadedMulterFileI,
            cardFourIcon?: UploadedMulterFileI,
        }
    ): Promise<AnalyticsDashboardSectionThreeCms | Error> {
        if (files) {
            if(files.cardOneIcon){
                const iconOne: any = await this.doSpaceService.uploadFile(files.cardOneIcon[0], "AnalyticsDashboardSectionThreeCms/");
                dto.cardOneIcon = iconOne;
            }
            if(files.cardTwoIcon){
                const iconTwo: any = await this.doSpaceService.uploadFile(files.cardTwoIcon[0], "AnalyticsDashboardSectionThreeCms/");
                dto.cardTwoIcon = iconTwo;
            }
            if(files.cardThreeIcon){
                const iconThree: any = await this.doSpaceService.uploadFile(files.cardThreeIcon[0], "AnalyticsDashboardSectionThreeCms/");
                dto.cardThreeIcon = iconThree;
            }
            if(files.cardFourIcon){
                const iconFour: any = await this.doSpaceService.uploadFile(files.cardFourIcon[0], "AnalyticsDashboardSectionThreeCms/");
                dto.cardFourIcon = iconFour;
            }
            
        }
        const isExists = await this.analyticsDashboardSectionThreeCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionThreeCms[] | Error> {
        const data = await this.analyticsDashboardSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}