import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { AnalyticsDashboardSectionTwoCmsService } from "./analytics-dashboard-section-two-cms.service";
import { UpdateAnalyticsDashboardSectionTwoCmsDto } from "./dto/update-analytics-dashboard-section-two-cms.dto";

@Controller({ path: "analytics-dashboard-section-two-cms", version: Constants.API_VERSION_1 })

export class AnalyticsDashboardSectionTwoCmsController {
    constructor(private readonly service: AnalyticsDashboardSectionTwoCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "attributeOneIcon", maxCount: 1 },
            { name: "attributeTwoIcon", maxCount: 1 },
            { name: "attributeThreeIcon", maxCount: 1 },
            { name: "attributeFourIcon", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateAnalyticsDashboardSectionTwoCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI,
            attributeOneIcon?: UploadedMulterFileI,
            attributeTwoIcon?: UploadedMulterFileI,
            attributeThreeIcon?: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
