import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AnalyticsDashboardSectionTwoCmsRepository } from "./analytics-dashboard-section-two-cms.repository";
import { AnalyticsDashboardSectionTwoCms } from "./schema/analytics-dashboard-section-two-cms.schema";
import { UpdateAnalyticsDashboardSectionTwoCmsDto } from "./dto/update-analytics-dashboard-section-two-cms.dto";

@Injectable()
export class AnalyticsDashboardSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('analytics_dashboard_section_two_cms')
        private readonly analyticsDashboardSectionTwoCmsModel: Model<AnalyticsDashboardSectionTwoCms>
    ) { }

    private readonly analyticsDashboardSectionTwoCmsRepository =
        new AnalyticsDashboardSectionTwoCmsRepository(this.analyticsDashboardSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateAnalyticsDashboardSectionTwoCmsDto,
        files: {
            image?: UploadedMulterFileI,
            attributeOneIcon?:UploadedMulterFileI,
            attributeTwoIcon?:UploadedMulterFileI,
            attributeThreeIcon?:UploadedMulterFileI,
            attributeFourIcon?:UploadedMulterFileI,
        }
    ): Promise<AnalyticsDashboardSectionTwoCms | Error> {
        if (files) {
            if(files.image){
                const img: any = await this.doSpaceService.uploadFile(files.image[0], "AnalyticsDashboardSectionTwoCms/");
                dto.image = img;
            }
            if(files.attributeOneIcon){
                const iconOne: any = await this.doSpaceService.uploadFile(files.attributeOneIcon[0], "AnalyticsDashboardSectionTwoCms/");
                dto.attributeOneIcon = iconOne;
            }
            if(files.attributeTwoIcon){
                const iconTwo: any = await this.doSpaceService.uploadFile(files.attributeTwoIcon[0], "AnalyticsDashboardSectionTwoCms/");
                dto.attributeTwoIcon = iconTwo;
            }
            if(files.attributeThreeIcon){
                const iconThree: any = await this.doSpaceService.uploadFile(files.attributeThreeIcon[0], "AnalyticsDashboardSectionTwoCms/");
                dto.attributeThreeIcon = iconThree;
            }
            if(files.attributeFourIcon){
                const iconFour: any = await this.doSpaceService.uploadFile(files.attributeFourIcon[0], "AnalyticsDashboardSectionTwoCms/");
                dto.attributeFourIcon = iconFour;
            }
            
        }
        const isExists = await this.analyticsDashboardSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.analyticsDashboardSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.analyticsDashboardSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AnalyticsDashboardSectionTwoCms[] | Error> {
        const data = await this.analyticsDashboardSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}