import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateAboutSectionOneCmsDto } from "./dto/update-about-section-one-cms.dto";
import { AboutSectionOneCmsService } from "./about-section-one-cms.service";

@Controller({ path: "about-section-one-cms", version: Constants.API_VERSION_1 })

export class AboutSectionOneCmsController {
    constructor(private readonly service: AboutSectionOneCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "boxTwoImageOne", maxCount: 1 },
            { name: "boxTwoImageTwo", maxCount: 1 },
            { name: "boxTwoImageThree", maxCount: 1 },
            { name: "boxTwoImageFour", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateAboutSectionOneCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI,
            boxTwoImageOne?: UploadedMulterFileI,
            boxTwoImageTwo?: UploadedMulterFileI,
            boxTwoImageThree?: UploadedMulterFileI,
            boxTwoImageFour?: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
