import mongoose, { Model, Types } from 'mongoose';
import { UpdateAboutSectionOneCmsDto } from './dto/update-about-section-one-cms.dto';
import { AboutSectionOneCms } from './schema/about-section-one-cms.schema';

export class AboutSectionOneCmsRepository<AboutSectionOneCmsDocument extends AboutSectionOneCms> {
    constructor(private readonly model: Model<AboutSectionOneCmsDocument>) { }

    async createEntity(data: UpdateAboutSectionOneCmsDto): Promise<AboutSectionOneCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<AboutSectionOneCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateAboutSectionOneCmsDto): Promise<AboutSectionOneCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<AboutSectionOneCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<AboutSectionOneCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}