import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateAboutSectionOneCmsDto } from "./dto/update-about-section-one-cms.dto";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AboutSectionOneCmsRepository } from "./about-section-one-cms.repository";
import { AboutSectionOneCms } from './schema/about-section-one-cms.schema';

@Injectable()
export class AboutSectionOneCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('about_section_one_cms')
        private readonly aboutSectionOneCmsModel: Model<AboutSectionOneCms>
    ) { }

    private readonly aboutSectionOneCmsRepository =
        new AboutSectionOneCmsRepository(this.aboutSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdateAboutSectionOneCmsDto,
        files: {
            image?: UploadedMulterFileI,
            boxTwoImageOne?: UploadedMulterFileI,
            boxTwoImageTwo?: UploadedMulterFileI,
            boxTwoImageThree?: UploadedMulterFileI,
            boxTwoImageFour?: UploadedMulterFileI,
        }
    ): Promise<AboutSectionOneCms | Error> {
        if (files) {
            if(files.image){
                const img: any = await this.doSpaceService.uploadFile(files.image[0], "AboutSectionOneCms/");
                dto.image = img;
            }
            if(files.boxTwoImageOne){
                const imgOne: any = await this.doSpaceService.uploadFile(files.boxTwoImageOne[0], "AboutSectionOneCms/");
                dto.boxTwoImageOne = imgOne;
            }
            if(files.boxTwoImageTwo){
                const imgTwo: any = await this.doSpaceService.uploadFile(files.boxTwoImageTwo[0], "AboutSectionOneCms/");
                dto.boxTwoImageTwo = imgTwo;
            }
            if(files.boxTwoImageThree){
                const imgThree: any = await this.doSpaceService.uploadFile(files.boxTwoImageThree[0], "AboutSectionOneCms/");
                dto.boxTwoImageThree = imgThree;
            }
            if(files.boxTwoImageFour){
                const imgFour: any = await this.doSpaceService.uploadFile(files.boxTwoImageFour[0], "AboutSectionOneCms/");
                dto.boxTwoImageFour = imgFour;
            }
        }
        const isExists = await this.aboutSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.aboutSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.aboutSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AboutSectionOneCms[] | Error> {
        const data = await this.aboutSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}