import mongoose, { Model, Types } from 'mongoose';
import { AboutSectionThreeCms } from './schema/about-section-three-cms.schema';
import { UpdateAboutSectionThreeDto } from './dto/update-about-section-three-cms.dto';

export class AboutSectionThreeCmsRepository<AboutSectionThreeDocument extends AboutSectionThreeCms> {
    constructor(private readonly model: Model<AboutSectionThreeDocument>) { }

    async createEntity(data: UpdateAboutSectionThreeDto): Promise<AboutSectionThreeDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<AboutSectionThreeDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateAboutSectionThreeDto): Promise<AboutSectionThreeDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<AboutSectionThreeDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<AboutSectionThreeDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}