import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { AboutSectionThreeCmsRepository } from './about-section-three-cms.repository';
import { UpdateAboutSectionThreeDto } from './dto/update-about-section-three-cms.dto';
import { AboutSectionThreeCms } from './schema/about-section-three-cms.schema';

@Injectable()
export class AboutSectionThreeCmsService {
    constructor(
        @InjectModel('about_section_three_cms')
        private readonly aboutSectionThreeCmsModel: Model<AboutSectionThreeCms>
    ) { }

    private readonly aboutSectionThreeCmsRepository = new AboutSectionThreeCmsRepository(
        this.aboutSectionThreeCmsModel
    );

    async updateOrCreateData(
        dto: UpdateAboutSectionThreeDto
    ): Promise<AboutSectionThreeCms | Error> {
        const isExists = await this.aboutSectionThreeCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.aboutSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.aboutSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<AboutSectionThreeCms[] | Error> {
        const data = await this.aboutSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
