import mongoose, { Model, Types } from 'mongoose';
import { AboutSectionTwoCms } from './schema/about-section-two-cms.schema';
import { UpdateAboutSectionTwoDto } from './dto/update-about-section-two-cms.dto';

export class AboutSectionTwoCmsRepository<AboutSectionDocument extends AboutSectionTwoCms> {
    constructor(private readonly model: Model<AboutSectionDocument>) { }

    async createEntity(data: UpdateAboutSectionTwoDto): Promise<AboutSectionDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<AboutSectionDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateAboutSectionTwoDto): Promise<AboutSectionDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<AboutSectionDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<AboutSectionDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}