import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { AboutSectionTwoCmsRepository } from './about-section-two-cms.repository';
import { UpdateAboutSectionTwoDto } from './dto/update-about-section-two-cms.dto';
import { AboutSectionTwoCms } from './schema/about-section-two-cms.schema';

@Injectable()
export class AboutSectionTwoCmsService {
    constructor(
        @InjectModel('about_section_two_cms')
        private readonly aboutSectionTwoCmsModel: Model<AboutSectionTwoCms>
    ) { }

    private readonly aboutSectionTwoCmsRepository = new AboutSectionTwoCmsRepository(
        this.aboutSectionTwoCmsModel
    );

    async updateOrCreateData(
        dto: UpdateAboutSectionTwoDto
    ): Promise<AboutSectionTwoCms | Error> {
        const isExists = await this.aboutSectionTwoCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.aboutSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.aboutSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<AboutSectionTwoCms[] | Error> {
        const data = await this.aboutSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
