import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { BookAConsultationPageCmsRepository } from './book-a-consultation-page-cms.repository';
import { UpdateBookAConsultationPageCmsDto } from './dto/update-book-a-consultation-page-cms.dto';
import { BookAConsultationPageCms } from './schema/book-a-consultation-page-cms.schema';

@Injectable()
export class BookAConsultationPageCmsService {
    constructor(
        @InjectModel('book_a_consultation_page_cms')
        private readonly bookAConsultationPageCmsModel: Model<BookAConsultationPageCms>
    ) { }

    private readonly bookAConsultationPageCmsRepository = new BookAConsultationPageCmsRepository(
        this.bookAConsultationPageCmsModel
    );

    async updateOrCreateData(
        dto: UpdateBookAConsultationPageCmsDto
    ): Promise<BookAConsultationPageCms | Error> {
        const isExists = await this.bookAConsultationPageCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.bookAConsultationPageCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.bookAConsultationPageCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<BookAConsultationPageCms[] | Error> {
        const data = await this.bookAConsultationPageCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
