import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { ChatbotPageSectionFourCms } from './schema/chatbot-page-section-four-cms.schema';
import { ChatbotPageSectionFourCmsRepository } from './chatbot-page-section-four-cms.repository';
import { UpdateChatbotPageSectionFourCmsDto } from './dto/update-chatbot-page-section-four-cms.dto';

@Injectable()
export class ChatbotPageSectionFourCmsService {
    constructor(
        @InjectModel('chatbot_page_section_four_cms')
        private readonly chatbotPageSectionFourCmsModel: Model<ChatbotPageSectionFourCms>
    ) { }

    private readonly chatbotPageSectionFourCmsRepository = new ChatbotPageSectionFourCmsRepository(
        this.chatbotPageSectionFourCmsModel
    );

    async updateOrCreateData(
        dto: UpdateChatbotPageSectionFourCmsDto
    ): Promise<ChatbotPageSectionFourCms | Error> {
        const isExists = await this.chatbotPageSectionFourCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.chatbotPageSectionFourCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.chatbotPageSectionFourCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<ChatbotPageSectionFourCms[] | Error> {
        const data = await this.chatbotPageSectionFourCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
