import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateChatbotSectionOneCmsDto } from "./dto/update-chatbot-section-one-cms.dto";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { ChatbotSectionOneCmsRepository } from "./chatbot-section-one-cms.repository";
import { ChatbotSectionOneCms } from "./schema/chatbot-section-one-cms.schema";

@Injectable()
export class ChatbotSectionOneCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('chatbot_section_one_cms')
        private readonly chatbotSectionOneCmsModel: Model<ChatbotSectionOneCms>
    ) { }

    private readonly chatbotSectionOneCmsRepository =
        new ChatbotSectionOneCmsRepository(this.chatbotSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdateChatbotSectionOneCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<ChatbotSectionOneCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "ChatbotSectionOneCms/");
            dto.image = img;
        }
        const isExists = await this.chatbotSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.chatbotSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.chatbotSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ChatbotSectionOneCms[] | Error> {
        const data = await this.chatbotSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}