import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateChatbotSectionThreeCmsDto } from "./dto/update-chatbot-section-three-cms.dto";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { ChatbotSectionThreeCms } from "./schema/chatbot-section-three-cms.schema";
import { ChatbotSectionThreeCmsRepository } from "./chatbot-section-three-cms.repository";

@Injectable()
export class ChatbotSectionThreeCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('chatbot_section_three_cms')
        private readonly chatbotSectionThreeCmsModel: Model<ChatbotSectionThreeCms>
    ) { }

    private readonly chatbotSectionThreeCmsRepository =
        new ChatbotSectionThreeCmsRepository(this.chatbotSectionThreeCmsModel);

    async updateOrCreateData(
        dto: UpdateChatbotSectionThreeCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<ChatbotSectionThreeCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "ChatbotSectionThreeCms/");
            dto.image = img;
        }
        const isExists = await this.chatbotSectionThreeCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.chatbotSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.chatbotSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ChatbotSectionThreeCms[] | Error> {
        const data = await this.chatbotSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}