import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateChatbotSectionTwoCmsDto } from "./dto/update-chatbot-section-two-cms.dto";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { ChatbotSectionTwoCmsRepository } from "./chatbot-section-two-cms.repository";
import { ChatbotSectionTwoCms } from "./schema/chatbot-section-two-cms.schema";

@Injectable()
export class ChatbotSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('chatbot_section_two_cms')
        private readonly chatbotSectionTwoCmsModel: Model<ChatbotSectionTwoCms>
    ) { }

    private readonly chatbotSectionTwoCmsRepository =
        new ChatbotSectionTwoCmsRepository(this.chatbotSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateChatbotSectionTwoCmsDto,
        files: {
            imageOne?: UploadedMulterFileI
            imageTwo?: UploadedMulterFileI
            imageThree?: UploadedMulterFileI
        }
    ): Promise<ChatbotSectionTwoCms | Error> {
        if (files) {
            if (files.imageOne) {
                const imgOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "ChatbotSectionTwoCms/");
                dto.imageOne = imgOne;
            }
            if (files.imageTwo) {
                const imgTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "ChatbotSectionTwoCms/");
                dto.imageTwo = imgTwo;
            }
            if (files.imageThree) {
                const imgThree: any = await this.doSpaceService.uploadFile(files.imageThree[0], "ChatbotSectionTwoCms/");
                dto.imageThree = imgThree;
            }
        }
        const isExists = await this.chatbotSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.chatbotSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.chatbotSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ChatbotSectionTwoCms[] | Error> {
        const data = await this.chatbotSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}