import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CheckoutSectionFourCmsRepository } from "./checkout-section-four-cms.repository";
import { UpdateCheckoutSectionFourCmsDto } from "./dto/update-checkout-section-four-cms.dto";
import { CheckoutSectionFourCms } from "./schema/checkout-section-four-cms.schema";

@Injectable()
export class CheckoutSectionFourCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('checkout_section_four_cms')
        private readonly checkoutSectionFourCmsModel: Model<CheckoutSectionFourCms>
    ) { }

    private readonly checkoutSectionFourCmsRepository =
        new CheckoutSectionFourCmsRepository(this.checkoutSectionFourCmsModel);

    async updateOrCreateData(
        dto: UpdateCheckoutSectionFourCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<CheckoutSectionFourCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "CheckoutSectionFourCms/");
            dto.image = img;
        }
        const isExists = await this.checkoutSectionFourCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.checkoutSectionFourCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.checkoutSectionFourCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CheckoutSectionFourCms[] | Error> {
        const data = await this.checkoutSectionFourCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}