import mongoose, { Model, Types } from 'mongoose';
import { UpdateCheckoutSectionOneCmsDto } from './dto/update-checkout-section-one-cms.dto';
import { CheckoutSectionOneCms } from './schema/checkout-section-one-cms.schema';

export class CheckoutSectionOneCmsRepository<CheckoutSectionOneCmsDocument extends CheckoutSectionOneCms> {
    constructor(private readonly model: Model<CheckoutSectionOneCmsDocument>) { }

    async createEntity(data: UpdateCheckoutSectionOneCmsDto): Promise<CheckoutSectionOneCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CheckoutSectionOneCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCheckoutSectionOneCmsDto): Promise<CheckoutSectionOneCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CheckoutSectionOneCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CheckoutSectionOneCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}