import mongoose, { Model, Types } from 'mongoose';
import { UpdateCheckoutSectionThreeCmsDto } from './dto/update-checkout-section-three-cms.dto';
import { CheckoutSectionThreeCms } from './schema/checkout-section-three-cms.schema';

export class CheckoutSectionThreeCmsRepository<CheckoutSectionThreeCmsDocument extends CheckoutSectionThreeCms> {
    constructor(private readonly model: Model<CheckoutSectionThreeCmsDocument>) { }

    async createEntity(data: UpdateCheckoutSectionThreeCmsDto): Promise<CheckoutSectionThreeCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CheckoutSectionThreeCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCheckoutSectionThreeCmsDto): Promise<CheckoutSectionThreeCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CheckoutSectionThreeCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CheckoutSectionThreeCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}