import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CheckoutSectionThreeCmsRepository } from "./checkout-section-three-cms.repository";
import { UpdateCheckoutSectionThreeCmsDto } from "./dto/update-checkout-section-three-cms.dto";
import { CheckoutSectionThreeCms } from "./schema/checkout-section-three-cms.schema";

@Injectable()
export class CheckoutSectionThreeCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('checkout_section_three_cms')
        private readonly checkoutSectionThreeCmsModel: Model<CheckoutSectionThreeCms>
    ) { }

    private readonly checkoutSectionThreeCmsRepository =
        new CheckoutSectionThreeCmsRepository(this.checkoutSectionThreeCmsModel);

    async updateOrCreateData(
        dto: UpdateCheckoutSectionThreeCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<CheckoutSectionThreeCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "CheckoutSectionThreeCms/");
            dto.image = img;
        }
        const isExists = await this.checkoutSectionThreeCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.checkoutSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.checkoutSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CheckoutSectionThreeCms[] | Error> {
        const data = await this.checkoutSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}