import mongoose, { Model, Types } from 'mongoose';
import { UpdateCheckoutSectionTwoCmsDto } from './dto/update-checkout-section-two-cms.dto';
import { CheckoutSectionTwoCms } from './schema/checkout-section-two-cms.schema';

export class CheckoutSectionTwoCmsRepository<CheckoutSectionTwoCmsDocument extends CheckoutSectionTwoCms> {
    constructor(private readonly model: Model<CheckoutSectionTwoCmsDocument>) { }

    async createEntity(data: UpdateCheckoutSectionTwoCmsDto): Promise<CheckoutSectionTwoCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CheckoutSectionTwoCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCheckoutSectionTwoCmsDto): Promise<CheckoutSectionTwoCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<CheckoutSectionTwoCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CheckoutSectionTwoCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}