import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { CheckoutSectionTwoCmsRepository } from "./checkout-section-two-cms.repository";
import { CheckoutSectionTwoCms } from "./schema/checkout-section-two-cms.schema";
import { UpdateCheckoutSectionTwoCmsDto } from "./dto/update-checkout-section-two-cms.dto";

@Injectable()
export class CheckoutSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('checkout_section_two_cms')
        private readonly checkoutSectionTwoCmsModel: Model<CheckoutSectionTwoCms>
    ) { }

    private readonly checkoutSectionTwoCmsRepository =
        new CheckoutSectionTwoCmsRepository(this.checkoutSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateCheckoutSectionTwoCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<CheckoutSectionTwoCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "CheckoutSectionTwoCms/");
            dto.image = img;
        }
        const isExists = await this.checkoutSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.checkoutSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.checkoutSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CheckoutSectionTwoCms[] | Error> {
        const data = await this.checkoutSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}