import mongoose, { Model, Types } from 'mongoose';
import { CommonPageCms } from './schema/common-page-cms.schema';
import { UpdateCommonPageCmsDto } from './dto/update-common-page-cms.dto';

export class CommonPageCmsRepository<CommonPageCmsDocument extends CommonPageCms> {
    constructor(private readonly model: Model<CommonPageCmsDocument>) { }

    async createEntity(data: UpdateCommonPageCmsDto): Promise<CommonPageCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<CommonPageCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateCommonPageCmsDto): Promise<CommonPageCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<CommonPageCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<CommonPageCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}