import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { CommonPageCms } from './schema/common-page-cms.schema';
import { CommonPageCmsRepository } from './common-page-cms.repository';
import { UpdateCommonPageCmsDto } from './dto/update-common-page-cms.dto';

@Injectable()
export class CommonPageCmsService {
    constructor(
        @InjectModel('common_page_cms')
        private readonly commonPageCmsModel: Model<CommonPageCms>
    ) { }

    private readonly commonPageCmsRepository = new CommonPageCmsRepository(
        this.commonPageCmsModel
    );

    async updateOrCreateData(
        dto: UpdateCommonPageCmsDto
    ): Promise<CommonPageCms | Error> {
        const isExists = await this.commonPageCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.commonPageCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.commonPageCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<CommonPageCms[] | Error> {
        const data = await this.commonPageCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
