import mongoose, { Model, Types } from 'mongoose';
import { ContactPageCms } from './schema/contact-page-cms.schema';
import { UpdateContactPageCmsDto } from './dto/update-contact-page-cms.dto';

export class ContactPageCmsRepository<ContactPageCmsDocument extends ContactPageCms> {
    constructor(private readonly model: Model<ContactPageCmsDocument>) { }

    async createEntity(data: UpdateContactPageCmsDto): Promise<ContactPageCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<ContactPageCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateContactPageCmsDto): Promise<ContactPageCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<ContactPageCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<ContactPageCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}