import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { ContactPageCms } from './schema/contact-page-cms.schema';
import { ContactPageCmsRepository } from './contact-page-cms.repository';
import { UpdateContactPageCmsDto } from './dto/update-contact-page-cms.dto';

@Injectable()
export class ContactPageCmsService {
    constructor(
        @InjectModel('contact_page_cms')
        private readonly contactPageCmsModel: Model<ContactPageCms>
    ) { }

    private readonly contactPageCmsRepository = new ContactPageCmsRepository(
        this.contactPageCmsModel
    );

    async updateOrCreateData(
        dto: UpdateContactPageCmsDto
    ): Promise<ContactPageCms | Error> {
        const isExists = await this.contactPageCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.contactPageCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.contactPageCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<ContactPageCms[] | Error> {
        const data = await this.contactPageCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
