import mongoose, { Model, Types } from 'mongoose';
import { UpdateHeaderFooterCmsDto } from './dto/update-header-footer-cms.dto';
import { HeaderFooterCms } from './schema/header-footer-cms.schema';

export class HeaderFooterCmsRepository<HeaderFooterCmsDocument extends HeaderFooterCms> {
    constructor(private readonly model: Model<HeaderFooterCmsDocument>) { }

    async createEntity(data: UpdateHeaderFooterCmsDto): Promise<HeaderFooterCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HeaderFooterCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHeaderFooterCmsDto): Promise<HeaderFooterCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<HeaderFooterCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HeaderFooterCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}