import mongoose, { Model, Types } from 'mongoose';
import { HireUsCms } from './schema/hire-us-cms.schema';
import { UpdateHireUsCmsDto } from './dto/update-hire-us-cms.dto';

export class HireUsCmsRepository<HireUsCmsDocument extends HireUsCms> {
    constructor(private readonly model: Model<HireUsCmsDocument>) { }

    async createEntity(data: UpdateHireUsCmsDto): Promise<HireUsCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HireUsCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHireUsCmsDto): Promise<HireUsCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<HireUsCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HireUsCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}