import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { HireUsCms } from './schema/hire-us-cms.schema';
import { UpdateHireUsCmsDto } from './dto/update-hire-us-cms.dto';
import { HireUsCmsRepository } from './hire-us-cms.repository';

@Injectable()
export class HireUsCmsService {
    constructor(
        @InjectModel('hire_us_cms')
        private readonly hireUsCmsModel: Model<HireUsCms>
    ) { }

    private readonly hireUsCmsRepository = new HireUsCmsRepository(
        this.hireUsCmsModel
    );

    async updateOrCreateData(
        dto: UpdateHireUsCmsDto
    ): Promise<HireUsCms | Error> {
        const isExists = await this.hireUsCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.hireUsCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.hireUsCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<HireUsCms[] | Error> {
        const data = await this.hireUsCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
