import mongoose, { Model, Types } from 'mongoose';
import { UpdateHomeCmDto } from './dto/update-home-cms.dto';
import { HomeCms } from './schema/home-cms.schema';

export class HomeCmsRepository<HomeCmsDocument extends HomeCms> {
    constructor(private readonly model: Model<HomeCmsDocument>) { }

    async createEntity(data: UpdateHomeCmDto): Promise<HomeCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomeCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomeCmDto): Promise<HomeCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<HomeCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomeCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}