import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { UpdateHomeCmDto } from './dto/update-home-cms.dto';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { HomeCms } from './schema/home-cms.schema';
import { HomeCmsRepository } from './home-cms-repository';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';

@Injectable()
export class HomeCmsService {
    constructor(
        @InjectModel('home_cms')
        private readonly homeCmsModel: Model<HomeCms>
    ) { }

    private readonly homeCmsRepository = new HomeCmsRepository(
        this.homeCmsModel
    );

    async updateOrCreateData(
        dto: UpdateHomeCmDto
    ): Promise<HomeCms | Error> {
        const isExists = await this.homeCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.homeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.homeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<HomeCms[] | Error> {
        const data = await this.homeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
