import mongoose, { Model, Types } from 'mongoose';
import { UpdateHomeCompanySloganCmsDto } from './dto/update-home-company-slogan-cms.dto';
import { HomeCompanySloganCms } from './schema/home-company-slogan-cms.schema';

export class HomeCompanySloganCmsRepository<HomeCompanySloganCmsDocument extends HomeCompanySloganCms> {
    constructor(private readonly model: Model<HomeCompanySloganCmsDocument>) { }

    async createEntity(data: UpdateHomeCompanySloganCmsDto): Promise<HomeCompanySloganCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomeCompanySloganCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomeCompanySloganCmsDto): Promise<HomeCompanySloganCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<HomeCompanySloganCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomeCompanySloganCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}