import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateHomeCompanySloganCmsDto } from './dto/update-home-company-slogan-cms.dto';

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { HomeCompanySloganCmsRepository } from "./home-company-slogan-cms.repository";
import { HomeCompanySloganCms } from "./schema/home-company-slogan-cms.schema";

@Injectable()
export class HomeCompanySloganCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('home_company_slogan_cms')
        private readonly homeCompnaySlognaCmsModel: Model<HomeCompanySloganCms>
    ) { }

    private readonly homeCompanySloganCmsRepository =
        new HomeCompanySloganCmsRepository(this.homeCompnaySlognaCmsModel);

    async updateOrCreateData(
        dto: UpdateHomeCompanySloganCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<HomeCompanySloganCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "HomeCompanySloganCms/");
            dto.image = img;
        }
        const isExists = await this.homeCompanySloganCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.homeCompanySloganCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.homeCompanySloganCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<HomeCompanySloganCms[] | Error> {
        const data = await this.homeCompanySloganCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}