import mongoose, { Model, Types } from 'mongoose';
import { UpdateHomeHeroCmDto } from './dto/update-home-hero-cms.dto';
import { HomeHeroCms } from './schema/home-hero-cms.schema';

export class HomeHeroCmsRepository<HomeHeroCmsDocument extends HomeHeroCms> {
    constructor(private readonly model: Model<HomeHeroCmsDocument>) { }

    async createEntity(data: UpdateHomeHeroCmDto): Promise<HomeHeroCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomeHeroCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomeHeroCmDto): Promise<HomeHeroCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<HomeHeroCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomeHeroCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}