import { HomeHeroCmsRepository } from './home-hero-cms-repository';
import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { UpdateHomeHeroCmDto } from './dto/update-home-hero-cms.dto';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { HomeHeroCms } from './schema/home-hero-cms.schema';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';

@Injectable()
export class HomeHeroCmsService {
    constructor(
        @InjectModel('home_hero_cms')
        private readonly homeHeroCmsModel: Model<HomeHeroCms>
    ) { }

    private readonly homeHeroCmsRepository = new HomeHeroCmsRepository(
        this.homeHeroCmsModel
    );

    async updateOrCreateData(
        dto: UpdateHomeHeroCmDto
    ): Promise<HomeHeroCms | Error> {
        const isExists = await this.homeHeroCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.homeHeroCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.homeHeroCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<HomeHeroCms[] | Error> {
        const data = await this.homeHeroCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
