import mongoose, { Model, Types } from 'mongoose';
import { UpdateHomeProjectCmDto } from './dto/update-home-project-cms.dto';
import { HomeProjectCms } from './schema/home-project-cms.schema';


export class HomeProjectCmsRepository<HomeProjectCmsDocument extends HomeProjectCms> {
    constructor(private readonly model: Model<HomeProjectCmsDocument>) { }

    async createEntity(data: UpdateHomeProjectCmDto): Promise<HomeProjectCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<HomeProjectCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateHomeProjectCmDto): Promise<HomeProjectCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<HomeProjectCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<HomeProjectCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}