import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { HomeProjectCmsRepository } from './home-project-cms-repository';
import { UpdateHomeProjectCmDto } from './dto/update-home-project-cms.dto';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { HomeProjectCms } from './schema/home-project-cms.schema';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';

@Injectable()
export class HomeProjectCmsService {
    constructor(
        @InjectModel('home_project_cms')
        private readonly homeProjectCmsModel: Model<HomeProjectCms>
    ) { }

    private readonly homeProjectCmsRepository = new HomeProjectCmsRepository(
        this.homeProjectCmsModel
    );

    async updateOrCreateData(
        dto: UpdateHomeProjectCmDto
    ): Promise<HomeProjectCms | Error> {
        const isExists = await this.homeProjectCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.homeProjectCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.homeProjectCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<HomeProjectCms[] | Error> {
        const data = await this.homeProjectCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
