import { Body, Controller, Get, Post, UploadedFiles, UseGuards, UseInterceptors } from '@nestjs/common';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { Constants } from 'src/utils/constants';
import { UpdateIntegrationsPageCMSDto } from './dto/update-integrations-page-cms.dto';
import { IntegrationsPageCMSService } from './integrations-page-cms.service';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';

@Controller({ path: "integrations-page-cms", version: Constants.API_VERSION_1 })
export class IntegrationsPageCMSController {
    constructor(private readonly IntegrationsPageCMSService: IntegrationsPageCMSService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "sectionThreeImage", maxCount: 1 }
        ]
    ))
    async updateOrCreateData(
        @Body() dto: UpdateIntegrationsPageCMSDto, 
        @UploadedFiles() files: {
            sectionThreeImage?: UploadedMulterFileI
        }
    ) {
        return await this.IntegrationsPageCMSService.updateOrCreateData(dto, files);
    }

    @Get()
    async findAll() {
        return await this.IntegrationsPageCMSService.findAll();
    }
}
