import mongoose, { Model, Types } from 'mongoose';
import { UpdateIntegrationsPageCMSDto } from './dto/update-integrations-page-cms.dto';
import { IntegrationsPageCMS } from './schema/integrations-page-cms.schema';

export class IntegrationsPageCMSRepository<IntegrationsPageCMSDocument extends IntegrationsPageCMS> {
    constructor(private readonly model: Model<IntegrationsPageCMSDocument>) { }

    async createEntity(data: UpdateIntegrationsPageCMSDto): Promise<IntegrationsPageCMSDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<IntegrationsPageCMSDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateIntegrationsPageCMSDto): Promise<IntegrationsPageCMSDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<IntegrationsPageCMSDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<IntegrationsPageCMSDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}