import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { UpdateIntegrationsPageCMSDto } from './dto/update-integrations-page-cms.dto';
import { IntegrationsPageCMSRepository } from './integrations-page-cms.repository';
import { IntegrationsPageCMS } from './schema/integrations-page-cms.schema';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class IntegrationsPageCMSService {
    constructor(
        @InjectModel('integrations_page_cms')
        private readonly integrationsPageCMSCmsModel: Model<IntegrationsPageCMS>,
        private readonly doSpaceService: DoSpacesService
    ) { }

    private readonly integrationsPageCMSRepository = new IntegrationsPageCMSRepository(
        this.integrationsPageCMSCmsModel
    );

    async updateOrCreateData(
        dto: UpdateIntegrationsPageCMSDto,
        files: {
            sectionThreeImage?: UploadedMulterFileI
        }
    ): Promise<IntegrationsPageCMS | Error> {
        if (files && files.sectionThreeImage) {
            const image: any = await this.doSpaceService.uploadFile(files.sectionThreeImage[0], "IntegrationsPageCms/");
            dto.sectionThreeImage = image;
        }
        const isExists = await this.integrationsPageCMSRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.integrationsPageCMSRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.integrationsPageCMSRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<IntegrationsPageCMS[] | Error> {
        const data = await this.integrationsPageCMSRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
