import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateIntegrationsPageSectionFiveCmsDto } from "./dto/update-integrations-page-section-five-cms.dto";
import { IntegrationsPageSectionFiveCmsService } from "./integrations-page-section-five-cms.service";

@Controller({ path: "integrations-page-section-Five-cms", version: Constants.API_VERSION_1 })

export class IntegrationsPageSectionFiveCmsController {
    constructor(private readonly service: IntegrationsPageSectionFiveCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "cardOneImage", maxCount: 1 },
            { name: "cardTwoImage", maxCount: 1 },
            { name: "cardThreeImage", maxCount: 1 }

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateIntegrationsPageSectionFiveCmsDto,
        @UploadedFiles() files: {
            cardOneImage?: UploadedMulterFileI,
            cardTwoImage?: UploadedMulterFileI,
            cardThreeImage?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
