import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateIntegrationsPageSectionFiveCmsDto } from "./dto/update-integrations-page-section-five-cms.dto";
import { IntegrationsPageSectionFiveCmsRepository } from "./integrations-page-section-five-cms.repository";
import { IntegrationsPageSectionFiveCms } from "./schema/integrations-page-section-five-cms.schema";

@Injectable()
export class IntegrationsPageSectionFiveCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('integrations_page_section_five_cms')
        private readonly integrationsPageSectionFiveCmsModel: Model<IntegrationsPageSectionFiveCms>
    ) { }

    private readonly integrationsPageSectionFiveCmsRepository =
        new IntegrationsPageSectionFiveCmsRepository(this.integrationsPageSectionFiveCmsModel);

    async updateOrCreateData(
        dto: UpdateIntegrationsPageSectionFiveCmsDto,
        files: {
            cardOneImage?: UploadedMulterFileI,
            cardTwoImage?: UploadedMulterFileI,
            cardThreeImage?: UploadedMulterFileI
        }
    ): Promise<IntegrationsPageSectionFiveCms | Error> {
        if (files && files.cardOneImage) {
            const img: any = await this.doSpaceService.uploadFile(files.cardOneImage[0], "IntegrationsPageSectionFiveCms/");
            dto.cardOneImage = img;
        }
        if (files && files.cardTwoImage) {
            const img: any = await this.doSpaceService.uploadFile(files.cardTwoImage[0], "IntegrationsPageSectionFiveCms/");
            dto.cardTwoImage = img;
        }

        if (files && files.cardThreeImage) {
            const img: any = await this.doSpaceService.uploadFile(files.cardThreeImage[0], "IntegrationsPageSectionFiveCms/");
            dto.cardThreeImage = img;
        }
        const isExists = await this.integrationsPageSectionFiveCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.integrationsPageSectionFiveCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.integrationsPageSectionFiveCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<IntegrationsPageSectionFiveCms[] | Error> {
        const data = await this.integrationsPageSectionFiveCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}