import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateIntegrationsPageSectionFourCmsDto } from "./dto/update-integrations-page-section-four-cms.dto";
import { IntegrationsPageSectionFourCmsService } from "./integrations-page-section-four-cms.service";

@Controller({ path: "integrations-page-section-four-cms", version: Constants.API_VERSION_1 })

export class IntegrationsPageSectionFourCmsController {
    constructor(private readonly service: IntegrationsPageSectionFourCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateIntegrationsPageSectionFourCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
