import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateIntegrationsPageSectionFourCmsDto } from "./dto/update-integrations-page-section-four-cms.dto";
import { IntegrationsPageSectionFourCmsRepository } from "./integrations-page-section-four-cms.repository";
import { IntegrationsPageSectionFourCms } from "./schema/integrations-page-section-four-cms.schema";

@Injectable()
export class IntegrationsPageSectionFourCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('integrations_page_section_four_cms')
        private readonly integrationsPageSectionFourCmsModel: Model<IntegrationsPageSectionFourCms>
    ) { }

    private readonly integrationsPageSectionFourCmsRepository =
        new IntegrationsPageSectionFourCmsRepository(this.integrationsPageSectionFourCmsModel);

    async updateOrCreateData(
        dto: UpdateIntegrationsPageSectionFourCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<IntegrationsPageSectionFourCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "IntegrationsPageSectionFourCms/");
            dto.image = img;
        }
        const isExists = await this.integrationsPageSectionFourCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.integrationsPageSectionFourCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.integrationsPageSectionFourCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<IntegrationsPageSectionFourCms[] | Error> {
        const data = await this.integrationsPageSectionFourCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}