import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateIntegrationsPageSectionSixCmsDto } from "./dto/update-integrations-page-section-six-cms.dto";
import { IntegrationsPageSectionSixCmsRepository } from "./integrations-page-section-six-cms.repository";
import { IntegrationsPageSectionSixCms } from "./schema/integrations-page-section-six-cms.schema";

@Injectable()
export class IntegrationsPageSectionSixCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('integrations_page_section_six_cms')
        private readonly integrationsPageSectionSixCmsModel: Model<IntegrationsPageSectionSixCms>
    ) { }

    private readonly integrationsPageSectionSixCmsRepository =
        new IntegrationsPageSectionSixCmsRepository(this.integrationsPageSectionSixCmsModel);

    async updateOrCreateData(
        dto: UpdateIntegrationsPageSectionSixCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<IntegrationsPageSectionSixCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "IntegrationsPageSectionSixCms/");
            dto.image = img;
        }
        const isExists = await this.integrationsPageSectionSixCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.integrationsPageSectionSixCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.integrationsPageSectionSixCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<IntegrationsPageSectionSixCms[] | Error> {
        const data = await this.integrationsPageSectionSixCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}