import { Body, Controller, Delete, Get, Param, Patch, Post, Query, UseGuards } from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { CreateIntegrationsPageSectionThreeDto } from "./dto/create-integrations-page-section-three.dto";
import { UpdateIntegrationsPageSectionThreeDto } from "./dto/update-integrations-page-section-three.dto";
import { IntegrationsPageSectionThreeService } from "./integrations-page-section-three.service";

@Controller({ path: "integrations-page-section-three", version: Constants.API_VERSION_1 })

export class IntegrationsPageSectionThreeController {
    constructor(private readonly service: IntegrationsPageSectionThreeService) { }

    @Post()
    // @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateIntegrationsPageSectionThreeDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string,
    ) {
        return this.service.findAll(pageParam, limitParam);
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(@Param("id") id: string, @Body() dto: UpdateIntegrationsPageSectionThreeDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.delete(id);
    }
}
