import mongoose, { Model, Types } from 'mongoose';
import { CreateIntegrationsPageSectionThreeDto } from './dto/create-integrations-page-section-three.dto';
import { UpdateIntegrationsPageSectionThreeDto } from './dto/update-integrations-page-section-three.dto';
import { IntegrationsPageSectionThree } from './schema/integrations-page-section-three.schema';

export class IntegrationsPageSectionThreeRepository<IntegrationsPageSectionThreeDocument extends IntegrationsPageSectionThree> {
    constructor(private readonly integrationsPageSectionThreeModel: Model<IntegrationsPageSectionThreeDocument>) { }

    async createEntity(data: CreateIntegrationsPageSectionThreeDto): Promise<IntegrationsPageSectionThree> {
        const createdEntity = new this.integrationsPageSectionThreeModel({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<IntegrationsPageSectionThree | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.integrationsPageSectionThreeModel.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateIntegrationsPageSectionThreeDto): Promise<IntegrationsPageSectionThree | null> {
        return await this.integrationsPageSectionThreeModel.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.integrationsPageSectionThreeModel.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<IntegrationsPageSectionThree[]> {
        return await this.integrationsPageSectionThreeModel.find({ isDeleted: false });
    }
    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.integrationsPageSectionThreeModel.countDocuments({ ...query, isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.integrationsPageSectionThreeModel
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 })

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.integrationsPageSectionThreeModel.countDocuments({
                isDeleted: false
            });
        } catch (e) {
            return e;
        }
    }
}