import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { CreateIntegrationsPageSectionThreeDto } from './dto/create-integrations-page-section-three.dto';
import { UpdateIntegrationsPageSectionThreeDto } from './dto/update-integrations-page-section-three.dto';
import { IntegrationsPageSectionThreeRepository } from './integrations-page-section-three.repository';
import { IntegrationsPageSectionThree } from './schema/integrations-page-section-three.schema';

@Injectable()
export class IntegrationsPageSectionThreeService {
    constructor(@InjectModel('integrations_page_section_three') private readonly IntegrationsPageSectionThreeModel: Model<IntegrationsPageSectionThree>) { }

    private readonly integrationsPageSectionThreeRepository = new IntegrationsPageSectionThreeRepository(this.IntegrationsPageSectionThreeModel);

    async create(dto: CreateIntegrationsPageSectionThreeDto): Promise<IntegrationsPageSectionThree> {
        const data = await this.integrationsPageSectionThreeRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data saved successfully.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string,): Promise<IntegrationsPageSectionThree[]> {

        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.integrationsPageSectionThreeRepository.paginate(page, limit);;
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<IntegrationsPageSectionThree | null> {
        const data = await this.integrationsPageSectionThreeRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateIntegrationsPageSectionThreeDto): Promise<IntegrationsPageSectionThree | null> {
        const res = await this.integrationsPageSectionThreeRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }
        const data = await this.integrationsPageSectionThreeRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.integrationsPageSectionThreeRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND
            );
        }

        const data = await this.integrationsPageSectionThreeRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}