import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { UpdateIntegrationsPageSectionTwoCmsDto } from "./dto/update-integrations-page-section-two-cms.dto";
import { IntegrationsPageSectionTwoCmsService } from "./integrations-page-section-two-cms.service";

@Controller({ path: "integrations-page-section-two-cms", version: Constants.API_VERSION_1 })

export class IntegrationsPageSectionTwoCmsController {
    constructor(private readonly service: IntegrationsPageSectionTwoCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "imageOne", maxCount: 1 },
            { name: "imageTwo", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateIntegrationsPageSectionTwoCmsDto,
        @UploadedFiles() files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
