import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateIntegrationsPageSectionTwoCmsDto } from "./dto/update-integrations-page-section-two-cms.dto";
import { IntegrationsPageSectionTwoCmsRepository } from "./integrations-page-section-two-cms.repository";
import { IntegrationsPageSectionTwoCms } from "./schema/integrations-page-section-two-cms.schema";

@Injectable()
export class IntegrationsPageSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('integrations_page_section_two_cms')
        private readonly integrationsPageSectionTwoCmsModel: Model<IntegrationsPageSectionTwoCms>
    ) { }

    private readonly integrationsPageSectionTwoCmsRepository =
        new IntegrationsPageSectionTwoCmsRepository(this.integrationsPageSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateIntegrationsPageSectionTwoCmsDto,
        files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI
        }
    ): Promise<IntegrationsPageSectionTwoCms | Error> {
        if (files && files.imageOne) {
            const img: any = await this.doSpaceService.uploadFile(files.imageOne[0], "IntegrationsPageSectionTwoCms/");
            dto.imageOne = img;
        }
        if (files && files.imageTwo) {
            const img: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "IntegrationsPageSectionTwoCms/");
            dto.imageTwo = img;
        }
        const isExists = await this.integrationsPageSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.integrationsPageSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.integrationsPageSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<IntegrationsPageSectionTwoCms[] | Error> {
        const data = await this.integrationsPageSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}