import mongoose, { Model, Types } from 'mongoose';
import { NewsletterCms } from './schema/newsletter-cms.schema';
import { UpdateNewsletterCmDto } from './dto/update-newsletter-cms.dto';

export class NewsletterCmsRepository<NewsletterCmsDocument extends NewsletterCms> {
    constructor(private readonly model: Model<NewsletterCmsDocument>) { }

    async createEntity(data: UpdateNewsletterCmDto): Promise<NewsletterCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<NewsletterCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateNewsletterCmDto): Promise<NewsletterCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<NewsletterCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<NewsletterCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}