import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { UpdateNewsletterCmDto } from './dto/update-newsletter-cms.dto';
import { NewsletterCms } from './schema/newsletter-cms.schema';
import { NewsletterCmsRepository } from './newsletter-cms-repository';

@Injectable()
export class NewsletterCmsService {
    constructor(
        @InjectModel('newsletter_cms')
        private readonly newsletterCmsModel: Model<NewsletterCms>
    ) { }

    private readonly newsletterCmsRepository = new NewsletterCmsRepository(
        this.newsletterCmsModel
    );

    async updateOrCreateData(
        dto: UpdateNewsletterCmDto
    ): Promise<NewsletterCms | Error> {
        const isExists = await this.newsletterCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.newsletterCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.newsletterCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<NewsletterCms[] | Error> {
        const data = await this.newsletterCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
