import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { PortfolioDetailsDiscoverCms } from './schema/portfolio-details-discover-cms.schema';
import { PortfolioDetailsDiscoverCmsRepository } from './portfolio-details-discover-repository';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { UpdatePortfolioDetailsDiscoverDto } from './dto/update-portfolio-details-discover-cms.dto';

@Injectable()
export class PortfolioDetailsDiscoverCmsService {
    constructor(
        @InjectModel('portfolio_details_discover_cms')
        private readonly portfolioDetailsDiscoverCmsModel: Model<PortfolioDetailsDiscoverCms>
    ) { }

    private readonly portfolioDetailsDiscoverCmsRepository = new PortfolioDetailsDiscoverCmsRepository(
        this.portfolioDetailsDiscoverCmsModel
    );

    async updateOrCreateData(
        dto: UpdatePortfolioDetailsDiscoverDto
    ): Promise<PortfolioDetailsDiscoverCms | Error> {
        const isExists = await this.portfolioDetailsDiscoverCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.portfolioDetailsDiscoverCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.portfolioDetailsDiscoverCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<PortfolioDetailsDiscoverCms[] | Error> {
        const data = await this.portfolioDetailsDiscoverCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
