import mongoose, { Model, Types } from 'mongoose';
import { PortfolioDetailsDiscoverCms } from './schema/portfolio-details-discover-cms.schema';
import { UpdatePortfolioDetailsDiscoverDto } from './dto/update-portfolio-details-discover-cms.dto';

export class PortfolioDetailsDiscoverCmsRepository<PortfolioDetailsDiscoverDocument extends PortfolioDetailsDiscoverCms> {
    constructor(private readonly model: Model<PortfolioDetailsDiscoverDocument>) { }

    async createEntity(data: UpdatePortfolioDetailsDiscoverDto): Promise<PortfolioDetailsDiscoverDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<PortfolioDetailsDiscoverDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdatePortfolioDetailsDiscoverDto): Promise<PortfolioDetailsDiscoverDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<PortfolioDetailsDiscoverDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<PortfolioDetailsDiscoverDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}