import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { PostPurchaseSectionFourCmsService } from "./post-purchase-section-four-cms.service";
import { UpdatePostPurchaseSectionFourCmsDto } from "./dto/update-post-purchase-section-four-cms.dto";

@Controller({ path: "post-purchase-section-four-cms", version: Constants.API_VERSION_1 })

export class PostPurchaseSectionFourCmsController {
    constructor(private readonly service: PostPurchaseSectionFourCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "imageOne", maxCount: 1 },
            { name: "imageTwo", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdatePostPurchaseSectionFourCmsDto,
        @UploadedFiles() files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
