import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdatePostPurchaseSectionFourCmsDto } from "./dto/update-post-purchase-section-four-cms.dto";
import { PostPurchaseSectionFourCmsRepository } from "./post-purchase-section-four-cms.repository";
import { PostPurchaseSectionFourCms } from "./schema/post-purchase-section-four-cms.schema";

@Injectable()
export class PostPurchaseSectionFourCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('post_purchase_section_four_cms')
        private readonly postPurchaseSectionFourCmsModel: Model<PostPurchaseSectionFourCms>
    ) { }

    private readonly postPurchaseSectionFourCmsRepository =
        new PostPurchaseSectionFourCmsRepository(this.postPurchaseSectionFourCmsModel);

    async updateOrCreateData(
        dto: UpdatePostPurchaseSectionFourCmsDto,
        files: {
            imageOne?: UploadedMulterFileI,
            imageTwo?: UploadedMulterFileI
        }
    ): Promise<PostPurchaseSectionFourCms | Error> {
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "PostPurchaseSectionFourCms/");
            dto.imageOne = imageOne;
        }
        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "PostPurchaseSectionFourCms/");
            dto.imageTwo = imageTwo;
        }
        const isExists = await this.postPurchaseSectionFourCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.postPurchaseSectionFourCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.postPurchaseSectionFourCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PostPurchaseSectionFourCms[] | Error> {
        const data = await this.postPurchaseSectionFourCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}