import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdatePostPurchaseSectionOneCmsDto } from "./dto/update-post-purchase-section-one-cms.dto";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { PostPurchaseSectionOneCmsRepository } from "./post-purchase-section-one-cms.repository";
import { PostPurchaseSectionOneCms } from "./schema/post-purchase-section-one-cms.schema";

@Injectable()
export class PostPurchaseSectionOneCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('post_purchase_section_one_cms')
        private readonly postPurchaseSectionOneCmsModel: Model<PostPurchaseSectionOneCms>
    ) { }

    private readonly postPurchaseSectionOneCmsRepository =
        new PostPurchaseSectionOneCmsRepository(this.postPurchaseSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdatePostPurchaseSectionOneCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<PostPurchaseSectionOneCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "PostPurchaseSectionOneCms/");
            dto.image = img;
        }
        const isExists = await this.postPurchaseSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.postPurchaseSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.postPurchaseSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PostPurchaseSectionOneCms[] | Error> {
        const data = await this.postPurchaseSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}