import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdatePostPurchaseSectionThreeCmsDto } from "./dto/update-post-purchase-section-three-cms.dto";
import { PostPurchaseSectionThreeCmsRepository } from "./post-purchase-section-three-cms.repository";
import { PostPurchaseSectionThreeCms } from "./schema/post-purchase-section-three-cms.schema";

@Injectable()
export class PostPurchaseSectionThreeCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('post_purchase_section_three_cms')
        private readonly postPurchaseSectionThreeCmsModel: Model<PostPurchaseSectionThreeCms>
    ) { }

    private readonly postPurchaseSectionThreeCmsRepository =
        new PostPurchaseSectionThreeCmsRepository(this.postPurchaseSectionThreeCmsModel);

    async updateOrCreateData(
        dto: UpdatePostPurchaseSectionThreeCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<PostPurchaseSectionThreeCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "PostPurchaseSectionThreeCms/");
            dto.image = img;
        }
        const isExists = await this.postPurchaseSectionThreeCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.postPurchaseSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.postPurchaseSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PostPurchaseSectionThreeCms[] | Error> {
        const data = await this.postPurchaseSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}