import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { PostPurchaseSectionTwoCmsService } from "./post-purchase-section-two-cms.service";
import { UpdatePostPurchaseSectionTwoCmsDto } from "./dto/update-post-purchase-section-two-cms.dto";

@Controller({ path: "post-purchase-section-two-cms", version: Constants.API_VERSION_1 })

export class PostPurchaseSectionTwoCmsController {
    constructor(private readonly service: PostPurchaseSectionTwoCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },

        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdatePostPurchaseSectionTwoCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
