import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdatePostPurchaseSectionTwoCmsDto } from "./dto/update-post-purchase-section-two-cms.dto";
import { PostPurchaseSectionTwoCmsRepository } from "./post-purchase-section-two-cms.repository";
import { PostPurchaseSectionTwoCms } from "./schema/post-purchase-section-two-cms.schema";

@Injectable()
export class PostPurchaseSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('post_purchase_section_two_cms')
        private readonly postPurchaseSectionTwoCmsModel: Model<PostPurchaseSectionTwoCms>
    ) { }

    private readonly postPurchaseSectionTwoCmsRepository =
        new PostPurchaseSectionTwoCmsRepository(this.postPurchaseSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdatePostPurchaseSectionTwoCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<PostPurchaseSectionTwoCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "PostPurchaseSectionTwoCms/");
            dto.image = img;
        }
        const isExists = await this.postPurchaseSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.postPurchaseSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.postPurchaseSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PostPurchaseSectionTwoCms[] | Error> {
        const data = await this.postPurchaseSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}