import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { UpdatePrivacyPolicyCmsDto } from './dto/update-privacy-policy-cms.dto';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { PrivacyPolicyCms } from './schema/privacy-policy-cms.schema';
import { PrivacyPolicyCmsRepository } from './privacy-policy-cms-repository';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';

@Injectable()
export class PrivacyPolicyCmsService {
    constructor(
        @InjectModel('privacy_policy_cms')
        private readonly privacyPolicyCmsModel: Model<PrivacyPolicyCms>
    ) { }

    private readonly privacyPolicyCmsRepository = new PrivacyPolicyCmsRepository(
        this.privacyPolicyCmsModel
    );

    async updateOrCreateData(
        dto: UpdatePrivacyPolicyCmsDto
    ): Promise<PrivacyPolicyCms | Error> {
        const isExists = await this.privacyPolicyCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.privacyPolicyCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.privacyPolicyCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<PrivacyPolicyCms[] | Error> {
        const data = await this.privacyPolicyCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
