import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateRobotTextCmsDto } from "./dto/update-robot-text-cms.dto";
import { RobotTextCmsRepository } from "./robot-text-cms.repository";
import { RobotTextCms } from "./schema/robot-text-cms.schema";

@Injectable()
export class RobotTextCmsService {
    constructor(
        @InjectModel('robot_text_cms')
        private readonly robotTextCmsModel: Model<RobotTextCms>
    ) { }

    private readonly robotTextCmsRepository = new RobotTextCmsRepository(this.robotTextCmsModel);

    async updateOrCreateData(dto: UpdateRobotTextCmsDto): Promise<RobotTextCms | Error> {
        const isExists = await this.robotTextCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.robotTextCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists?._id.toString();
            const data = await this.robotTextCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<RobotTextCms[] | Error> {
        const data = await this.robotTextCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}