import mongoose, { Model, Types } from 'mongoose';
import { UpdateSiteMapCmsDto } from './dto/update-site-map-cms.dto';
import { SiteMapCms } from './schema/site-map-cms.schema';

export class SiteMapCmsRepository<SiteMapCmsDocument extends SiteMapCms> {
    constructor(private readonly model: Model<SiteMapCmsDocument>) { }

    async createEntity(data: UpdateSiteMapCmsDto): Promise<SiteMapCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<SiteMapCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateSiteMapCmsDto): Promise<SiteMapCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<SiteMapCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<SiteMapCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async findByFilterQuery(query: any): Promise<SiteMapCmsDocument[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }
}