import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UpdateSiteMapCmsDto } from "./dto/update-site-map-cms.dto";
import { SiteMapCms } from "./schema/site-map-cms.schema";
import { SiteMapCmsRepository } from "./site-map-cms.repository";

@Injectable()
export class SiteMapCmsService {
    constructor(
        @InjectModel('site_map_cms')
        private readonly siteMapCmsModel: Model<SiteMapCms>
    ) { }

    private readonly siteMapCmsRepository = new SiteMapCmsRepository(this.siteMapCmsModel);

    async updateOrCreateData(dto: UpdateSiteMapCmsDto): Promise<SiteMapCms | Error> {
        const isExists = await this.siteMapCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.siteMapCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists?._id.toString();
            const data = await this.siteMapCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<SiteMapCms[] | Error> {
        const data = await this.siteMapCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}