import mongoose, { Model, Types } from 'mongoose';
import { UpdateSolutionServiceDetailsCmsDto } from './dto/update-solution-service-details-cms.dto';
import { SolutionServiceDetailsCms } from './schema/solution-service-details-cms.schema';

export class SolutionServiceDetailsCmsRepository<SolutionServiceDetailsCmsDocument extends SolutionServiceDetailsCms> {
    constructor(private readonly model: Model<SolutionServiceDetailsCmsDocument>) { }

    async createEntity(data: UpdateSolutionServiceDetailsCmsDto): Promise<SolutionServiceDetailsCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<SolutionServiceDetailsCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateSolutionServiceDetailsCmsDto): Promise<SolutionServiceDetailsCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<SolutionServiceDetailsCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<SolutionServiceDetailsCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}