import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { SolutionServiceDetailsCmsRepository } from './solution-service-details-cms-repository';
import { UpdateSolutionServiceDetailsCmsDto } from './dto/update-solution-service-details-cms.dto';
import { SolutionServiceDetailsCms } from './schema/solution-service-details-cms.schema';

@Injectable()
export class SolutionServiceDetailsCmsService {
    constructor(
        @InjectModel('solution_service_details_cms')
        private readonly solutionServiceDetailsCmsModel: Model<SolutionServiceDetailsCms>
    ) { }

    private readonly solutionServiceDetailsCmsRepository = new SolutionServiceDetailsCmsRepository(
        this.solutionServiceDetailsCmsModel
    );

    async updateOrCreateData(
        dto: UpdateSolutionServiceDetailsCmsDto
    ): Promise<SolutionServiceDetailsCms | Error> {
        const isExists = await this.solutionServiceDetailsCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.solutionServiceDetailsCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.solutionServiceDetailsCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<SolutionServiceDetailsCms[] | Error> {
        const data = await this.solutionServiceDetailsCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
