import mongoose, { Model, Types } from 'mongoose';
import { SolutionTypeDetailsCms } from './schema/solution-type-details-cms.schema';
import { UpdateSolutionTypeDetailsCmsDto } from './dto/update-solution-type-details-cms.dto';

export class SolutionTypeDetailsCmsRepository<SolutionTypeDetailsCmsDocument extends SolutionTypeDetailsCms> {
    constructor(private readonly model: Model<SolutionTypeDetailsCmsDocument>) { }

    async createEntity(data: UpdateSolutionTypeDetailsCmsDto): Promise<SolutionTypeDetailsCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<SolutionTypeDetailsCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateSolutionTypeDetailsCmsDto): Promise<SolutionTypeDetailsCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<SolutionTypeDetailsCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<SolutionTypeDetailsCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}