import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { SolutionTypeDetailsCmsRepository } from './solution-type-details-cms-repository';
import { SolutionTypeDetailsCms } from './schema/solution-type-details-cms.schema';
import { UpdateSolutionTypeDetailsCmsDto } from './dto/update-solution-type-details-cms.dto';

@Injectable()
export class SolutionTypeDetailsCmsService {
    constructor(
        @InjectModel('solution_type_details_cms')
        private readonly solutionTypeDetailsCmsModel: Model<SolutionTypeDetailsCms>
    ) { }

    private readonly solutionTypeDetailsCmsRepository = new SolutionTypeDetailsCmsRepository(
        this.solutionTypeDetailsCmsModel
    );

    async updateOrCreateData(
        dto: UpdateSolutionTypeDetailsCmsDto
    ): Promise<SolutionTypeDetailsCms | Error> {
        const isExists = await this.solutionTypeDetailsCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.solutionTypeDetailsCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.solutionTypeDetailsCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<SolutionTypeDetailsCms[] | Error> {
        const data = await this.solutionTypeDetailsCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
