import mongoose, { Model, Types } from 'mongoose';
import { StatisticsCms } from './schema/statistics-cms.schema';
import { UpdateStatisticsCmDto } from './dto/update-statistics-cms.dto';

export class StatisticsCmsRepository<StatisticsCmsDocument extends StatisticsCms> {
    constructor(private readonly model: Model<StatisticsCmsDocument>) { }

    async createEntity(data: UpdateStatisticsCmDto): Promise<StatisticsCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<StatisticsCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateStatisticsCmDto): Promise<StatisticsCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }

    async findAll(): Promise<StatisticsCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<StatisticsCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }
}