import { BadRequestException, HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { ResponseUtils } from 'src/utils/response.utils';
import { Constants } from 'src/utils/constants';
import { StatisticsCmsRepository } from './statistics-cms-repository';
import { StatisticsCms } from './schema/statistics-cms.schema';
import { UpdateStatisticsCmDto } from './dto/update-statistics-cms.dto';

@Injectable()
export class StatisticsCmsService {
    constructor(
        @InjectModel('statistics_cms')
        private readonly statisticsCmsModel: Model<StatisticsCms>
    ) { }

    private readonly statisticsCmsRepository = new StatisticsCmsRepository(
        this.statisticsCmsModel
    );

    async updateOrCreateData(
        dto: UpdateStatisticsCmDto
    ): Promise<StatisticsCms | Error> {
        const isExists = await this.statisticsCmsRepository.findOneByFilterQuery({
            isDeleted: false
        });
        if (!isExists) {
            const data = await this.statisticsCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(
                201,
                'Data created successfully!',
                'data',
                data
            );
        } else {
            const id = isExists?._id.toString();
            const data = await this.statisticsCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(
                200,
                'Data updated successfully!',
                'data',
                data
            );
        }
    }

    async findAll(): Promise<StatisticsCms[] | Error> {
        const data = await this.statisticsCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }


}
