import mongoose, { Model, Types } from 'mongoose';
import { DashboardSectionFiveCms } from './schema/dashboard-section-four-cms.schema';
import { UpdateDashboardSectionFiveCmsDto } from './dto/update-dashboard-section-five-cms.dto';

export class DashboardSectionFiveCmsRepository<DashboardSectionFiveCmsDocument extends DashboardSectionFiveCms> {
    constructor(private readonly model: Model<DashboardSectionFiveCmsDocument>) { }

    async createEntity(data: UpdateDashboardSectionFiveCmsDto): Promise<DashboardSectionFiveCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<DashboardSectionFiveCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateDashboardSectionFiveCmsDto): Promise<DashboardSectionFiveCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<DashboardSectionFiveCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<DashboardSectionFiveCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}