import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DashboardSectionFiveCms } from "./schema/dashboard-section-four-cms.schema";
import { DashboardSectionFiveCmsRepository } from "./dashboard-section-five-cms.repository";
import { UpdateDashboardSectionFiveCmsDto } from "./dto/update-dashboard-section-five-cms.dto";

@Injectable()
export class DashboardSectionFiveCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('dashboard_section_five_cms')
        private readonly dashboardSectionFiveCmsModel: Model<DashboardSectionFiveCms>
    ) { }

    private readonly dashboardSectionFiveCmsRepository = new DashboardSectionFiveCmsRepository(this.dashboardSectionFiveCmsModel);

    async updateOrCreateData(
        dto: UpdateDashboardSectionFiveCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<DashboardSectionFiveCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "DashboardSectionFiveCms/");
            dto.image = img;
        }
        const isExists = await this.dashboardSectionFiveCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.dashboardSectionFiveCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.dashboardSectionFiveCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DashboardSectionFiveCms[] | Error> {
        const data = await this.dashboardSectionFiveCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}