import { Body, Controller, Get, HttpCode, HttpStatus, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { Constants } from "src/utils/constants";
import { DashboardSectionFourCmsService } from "./dashboard-section-four-cms.service";
import { UpdateDashboardSectionFourCmsDto } from "./dto/update-dashboard-section-four-cms.dto";

@Controller({ path: "dashboard-section-four-cms", version: Constants.API_VERSION_1 })

export class DashboardSectionFourCmsController {
    constructor(private readonly service: DashboardSectionFourCmsService) {}

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateDashboardSectionFourCmsDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
