import mongoose, { Model, Types } from 'mongoose';
import { DashboardSectionFourCms } from './schema/dashboard-section-four-cms.schema';
import { UpdateDashboardSectionFourCmsDto } from './dto/update-dashboard-section-four-cms.dto';

export class DashboardSectionFourCmsRepository<DashboardSectionFourCmsDocument extends DashboardSectionFourCms> {
    constructor(private readonly model: Model<DashboardSectionFourCmsDocument>) { }

    async createEntity(data: UpdateDashboardSectionFourCmsDto): Promise<DashboardSectionFourCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<DashboardSectionFourCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateDashboardSectionFourCmsDto): Promise<DashboardSectionFourCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<DashboardSectionFourCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<DashboardSectionFourCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}