import mongoose, { Model, Types } from 'mongoose';
import { DashboardSectionOneCms } from './schema/dashboard-section-one-cms.schema';
import { UpdateDashboardSectionOneCmsDto } from './dto/update-dashboard-section-one-cms.dto';

export class DashboardSectionOneCmsRepository<DashboardSectionOneCmsDocument extends DashboardSectionOneCms> {
    constructor(private readonly model: Model<DashboardSectionOneCmsDocument>) { }

    async createEntity(data: UpdateDashboardSectionOneCmsDto): Promise<DashboardSectionOneCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<DashboardSectionOneCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateDashboardSectionOneCmsDto): Promise<DashboardSectionOneCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<DashboardSectionOneCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<DashboardSectionOneCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}