import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DashboardSectionOneCmsRepository } from "./dashboard-section-one-cms.repository";
import { UpdateDashboardSectionOneCmsDto } from "./dto/update-dashboard-section-one-cms.dto";
import { DashboardSectionOneCms } from "./schema/dashboard-section-one-cms.schema";

@Injectable()
export class DashboardSectionOneCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('dashboard_section_one_cms')
        private readonly dashboardSectionOneCmsModel: Model<DashboardSectionOneCms>
    ) { }

    private readonly dashboardSectionOneCmsRepository =
        new DashboardSectionOneCmsRepository(this.dashboardSectionOneCmsModel);

    async updateOrCreateData(
        dto: UpdateDashboardSectionOneCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<DashboardSectionOneCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "DashboardSectionOneCms/");
            dto.image = img;
        }
        const isExists = await this.dashboardSectionOneCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.dashboardSectionOneCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.dashboardSectionOneCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DashboardSectionOneCms[] | Error> {
        const data = await this.dashboardSectionOneCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}