import mongoose, { Model, Types } from 'mongoose';
import { DashboardSectionThreeCms } from './schema/dashboard-section-three-cms.schema';
import { UpdateDashboardSectionThreeCmsDto } from './dto/update-dashboard-section-three-cms.dto';

export class DashboardSectionThreeCmsRepository<DashboardSectionThreeCmsDocument extends DashboardSectionThreeCms> {
    constructor(private readonly model: Model<DashboardSectionThreeCmsDocument>) { }

    async createEntity(data: UpdateDashboardSectionThreeCmsDto): Promise<DashboardSectionThreeCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<DashboardSectionThreeCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateDashboardSectionThreeCmsDto): Promise<DashboardSectionThreeCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<DashboardSectionThreeCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<DashboardSectionThreeCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}