import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DashboardSectionThreeCms } from "./schema/dashboard-section-three-cms.schema";
import { DashboardSectionThreeCmsRepository } from "./dashboard-section-three-cms.repository";
import { UpdateDashboardSectionThreeCmsDto } from "./dto/update-dashboard-section-three-cms.dto";

@Injectable()
export class DashboardSectionThreeCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('dashboard_section_three_cms')
        private readonly dashboardSectionThreeCmsModel: Model<DashboardSectionThreeCms>
    ) { }

    private readonly dashboardSectionThreeCmsRepository = new DashboardSectionThreeCmsRepository(this.dashboardSectionThreeCmsModel);

    async updateOrCreateData(
        dto: UpdateDashboardSectionThreeCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<DashboardSectionThreeCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "DashboardSectionThreeCms/");
            dto.image = img;
        }
        const isExists = await this.dashboardSectionThreeCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.dashboardSectionThreeCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.dashboardSectionThreeCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DashboardSectionThreeCms[] | Error> {
        const data = await this.dashboardSectionThreeCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}