import mongoose, { Model, Types } from 'mongoose';
import { UpdateDashboardSectionTwoCmsDto } from './dto/update-dashboard-section-two-cms.dto';
import { DashboardSectionTwoCms } from './schema/dashboard-section-two-cms.schema';

export class DashboardSectionTwoCmsRepository<DashboardSectionTwoCmsDocument extends DashboardSectionTwoCms> {
    constructor(private readonly model: Model<DashboardSectionTwoCmsDocument>) { }

    async createEntity(data: UpdateDashboardSectionTwoCmsDto): Promise<DashboardSectionTwoCmsDocument> {
        try {
            const createdEntity = new this.model({
                ...data,
                _id: new Types.ObjectId()
            });
            return await createdEntity.save();
        } catch (err) {
            console.log(err);
        }
    }

    async findOneEntity(id: string): Promise<DashboardSectionTwoCmsDocument | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateDashboardSectionTwoCmsDto): Promise<DashboardSectionTwoCmsDocument | null> {
        try {
            return await this.model.findByIdAndUpdate(id, data, { new: true });
        } catch (err) {
            console.log(err);
        }
    }
    
    async findAll(): Promise<DashboardSectionTwoCmsDocument[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneByFilterQuery(query: any): Promise<DashboardSectionTwoCmsDocument | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

}