import { BadRequestException, HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectModel } from "@nestjs/mongoose";
import { Model } from "mongoose";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";

import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DashboardSectionTwoCmsRepository } from "./dashboard-section-two-cms.repository";
import { UpdateDashboardSectionTwoCmsDto } from "./dto/update-dashboard-section-two-cms.dto";
import { DashboardSectionTwoCms } from "./schema/dashboard-section-two-cms.schema";

@Injectable()
export class DashboardSectionTwoCmsService {
    constructor(
        private readonly doSpaceService: DoSpacesService,
        @InjectModel('dashboard_section_two_cms')
        private readonly dashboardSectionTwoCmsModel: Model<DashboardSectionTwoCms>
    ) { }

    private readonly dashboardSectionTwoCmsRepository =
        new DashboardSectionTwoCmsRepository(this.dashboardSectionTwoCmsModel);

    async updateOrCreateData(
        dto: UpdateDashboardSectionTwoCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<DashboardSectionTwoCms | Error> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "DashboardSectionTwoCms/");
            dto.image = img;
        }
        const isExists = await this.dashboardSectionTwoCmsRepository.findOneByFilterQuery({ isDeleted: false });
        if (!isExists) {
            const data = await this.dashboardSectionTwoCmsRepository.createEntity(dto);
            if (!data) {
                throw new BadRequestException(`Failed to create data!`);
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            const id = isExists?._id.toString();
            const data = await this.dashboardSectionTwoCmsRepository.updateEntity(id, dto);
            if (!data) {
                throw new BadRequestException(`Failed to update data!`);
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<DashboardSectionTwoCms[] | Error> {
        const data = await this.dashboardSectionTwoCmsRepository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}