import mongoose, { Model, Types } from "mongoose";
import { CreateChangePasswordTokenDto } from "./dto/create-change-password-token.dto";
import { UpdateChangePasswordTokenDto } from "./dto/update-change-password-token.dto";
import { ChangePasswordToken } from "./schema/change-password-token.schema";

export class ChangePasswordTokenRepository<ChangePasswordTokenDocument extends ChangePasswordToken> {
    constructor(private readonly model: Model<ChangePasswordTokenDocument>) { }

    async createEntity(data: CreateChangePasswordTokenDto): Promise<ChangePasswordTokenDocument> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findAll(): Promise<ChangePasswordToken[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneEntity(id: string): Promise<ChangePasswordToken | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateChangePasswordTokenDto): Promise<ChangePasswordToken | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findByFilterQuery(query: any): Promise<ChangePasswordToken[] | null> {
        return await this.model.find({ ...query, isDeleted: false })
    }

    async findOneByFilterQuery(query: any): Promise<ChangePasswordToken | null> {
        return await this.model.findOne({ ...query, isDeleted: false }).lean();
    }

    async paginate(page: number, limit: number) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({});
        const totalPages = Math.ceil(total / limit);

        const data = await this.model
            .find({ isDeleted: false })
            .skip(skip)
            .limit(limit);

        return {
            data,
            page,
            limit,
            total,
            totalPages
        };
    }
}