import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { CreateClientsDto } from './dto/create-clients.dto';
import { UpdateClientsDto } from './dto/update-clients.dto';
import { Clients } from './schema/clients.schema';
import { ClientsRepository } from './clients.repository';



@Injectable()
export class ClientsService {
    constructor(private readonly doSpaceService: DoSpacesService,
        @InjectModel('clients') private readonly clientsModel: Model<Clients>) { }

    private readonly clientsRepository = new ClientsRepository(this.clientsModel);

    async create(dto: CreateClientsDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Clients> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Clients/");
            dto.image = img;
        }

        const data = await this.clientsRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to Clients.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<Clients[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.clientsRepository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<Clients | null> {
        const data = await this.clientsRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateClientsDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Clients | null> {
        const res = await this.clientsRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const foundImage = (res as Clients)?.image;
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Clients/");
            dto.image = img;
        } else {
            dto.image = foundImage;
        }

        const data = await this.clientsRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.clientsRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.clientsRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }

    async updateClientsPosition(dto: any): Promise<any | Error> {
        if (dto.dataList) {
            for (const element of dto.dataList) {
                const res = await this.clientsRepository.updateEntityByID(element);
            }
        }

        const data = await this.clientsRepository.findAll();

        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }
}