import mongoose, { Model, Types } from 'mongoose';
import { CreateConsultationDto } from './dto/create-consultation.dto';
import { UpdateConsultationDto } from './dto/update-consultation.dto';
import { Consultation } from './schema/consultation.schema';

export class ConsultationRepository<ConsultationDocument extends Consultation> {
    constructor(private readonly ConsultationModel: Model<ConsultationDocument>) { }

    async createEntity(data: CreateConsultationDto): Promise<Consultation> {
        const createdEntity = new this.ConsultationModel({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<Consultation | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.ConsultationModel.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateConsultationDto): Promise<Consultation | null> {
        return await this.ConsultationModel.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.ConsultationModel.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<Consultation[]> {
        return await this.ConsultationModel.find({ isDeleted: false });
    }
    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.ConsultationModel.countDocuments({ ...query, isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.ConsultationModel
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 })

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.ConsultationModel.countDocuments({
                isDeleted: false
            });
        } catch (e) {
            return e;
        }
    }
}