import mongoose, { Model, Types } from 'mongoose';
import { CreateIntegrationsDto } from './dto/create-integrations.dto';
import { UpdateIntegrationsDto } from './dto/update-integrations.dto';
import { Integrations } from './schema/integrations.schema';



export class IntegrationsRepository<IntegrationsDocument extends Integrations> {
    constructor(private readonly model: Model<IntegrationsDocument>) { }

    async createEntity(data: CreateIntegrationsDto): Promise<Integrations> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<Integrations | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }

        // return await this.model.findById(id);
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateIntegrationsDto): Promise<Integrations | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }
    async paginate(page: number, limit: number, query?: any) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({ ...query, isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.model
            .find({ ...query, isDeleted: false })
            .skip(skip)
            .limit(limit)
            .sort({ createdAt: -1 })

        return {
            data: data,
            pageCount: pageCount,
            total: total
        };
    }

    async deleteEntity(id: string): Promise<boolean> {
        // const data = await this.model.findByIdAndDelete(id);
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<Integrations[]> {
        return await this.model.find({ isDeleted: false });
    }
}