import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { CreateIntegrationsDto } from './dto/create-integrations.dto';
import { UpdateIntegrationsDto } from './dto/update-integrations.dto';
import { Integrations } from './schema/integrations.schema';
import { IntegrationsRepository } from './integrations.repository';



@Injectable()
export class IntegrationsService {
    constructor(private readonly doSpaceService: DoSpacesService,
        @InjectModel('integrations') private readonly integrationsModel: Model<Integrations>) { }

    private readonly integrationsRepository = new IntegrationsRepository(this.integrationsModel);

    async create(dto: CreateIntegrationsDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Integrations> {
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Integrations/");
            dto.image = img;
        }

        const data = await this.integrationsRepository.createEntity(dto);
        if (!data) {
            throw new BadRequestException(
                Constants.CREATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(201, "Successfully added to Integrations.", "data", data);
    }

    async findAll(pageParam?: string, limitParam?: string): Promise<Integrations[]> {
        const page = parseInt(pageParam, 10) ? parseInt(pageParam, 10) : 1;
        const limit = parseInt(limitParam, 10) ? parseInt(limitParam, 10) : 10;
        const data = await this.integrationsRepository.paginate(page, limit);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<Integrations | null> {
        const data = await this.integrationsRepository.findOneEntity(id);
        if (!data) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async update(id: string, dto: UpdateIntegrationsDto,
        files: {
            image?: UploadedMulterFileI
        }): Promise<Integrations | null> {
        const res = await this.integrationsRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }
        const foundImage = (res as Integrations)?.image;
        if (files && files.image) {
            const img: any = await this.doSpaceService.uploadFile(files.image[0], "Integrations/");
            dto.image = img;
        } else {
            dto.image = foundImage;
        }

        const data = await this.integrationsRepository.updateEntity(id, dto);
        if (!data) {
            throw new BadRequestException(
                Constants.UPDATE_FAILED,
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
    }

    async delete(id: string): Promise<void> {
        const res = await this.integrationsRepository.findOneEntity(id);
        if (!res) {
            throw new NotFoundException(
                Constants.NOT_FOUND,
            );
        }

        const data = await this.integrationsRepository.deleteEntity(id);
        if (!data) {
            throw new BadRequestException(
                Constants.DELETE_FAILED,
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}