import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { MongooseModule } from "@nestjs/mongoose";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { UsersSchema } from "../users/schema/users.schema";
import { NewsletterSubscriptionController } from "./newsletter-subscription.controller";
import { NewsletterSubscriptionService } from "./newsletter-subscription.service";
import { NewsletterSubscriptionSchema } from "./schema/newsletter-subscription.schema";

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MongooseModule.forFeature([{ name: 'Users', schema: UsersSchema },
        { name: 'newsletter_subscription', schema: NewsletterSubscriptionSchema }]),
    ],
    controllers: [NewsletterSubscriptionController],
    providers: [NewsletterSubscriptionService, JwtHelper]
})
export class NewsletterSubscriptionModule {
}
