import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors,
} from '@nestjs/common';
import { Constants } from 'src/utils/constants';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { PortfolioService } from './portfolio.service';
import { CreatePortfolioDto } from './dto/create-portfolio.dto';
import { UpdatePortfolioDto } from './dto/update-portfolio.dto';

@Controller({ path: 'portfolio', version: Constants.API_VERSION_1 })
export class PortfolioController {
    constructor(private readonly service: PortfolioService) { }

    @Post("/portfolio-position")
    @UseGuards(AdminAuthGuard)
    updatePortfolioPosition(@Body() dto: any) {
        return this.service.updatePortfolioPosition(dto);
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(
        FileFieldsInterceptor([
            { name: 'featuredImage', maxCount: 1 },
            { name: 'images', maxCount: 5 },
        ]),
    )
    async create(
        @Body() dto: CreatePortfolioDto,
        @UploadedFiles()
        files: {
            featuredImage?: UploadedMulterFileI;
            images?: UploadedMulterFileI[];
        },
    ) {
        return await this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    async findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string,
    ) {
        return await this.service.findAll(pageParam, limitParam);
    }

    @Get('/form-data')
    @UseGuards(AdminAuthGuard)
    async findAllPortfolioFormData() {
        return await this.service.findAllPortfolioFormData();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    async findOne(@Param('id') id: string) {
        return await this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(
        FileFieldsInterceptor([
            { name: 'featuredImage', maxCount: 1 },
            { name: 'images', maxCount: 20 },
        ]),
    )
    async update(
        @Param('id') id: string,
        @Body() dto: UpdatePortfolioDto,
        @UploadedFiles()
        files: {
            featuredImage?: UploadedMulterFileI;
            images?: UploadedMulterFileI[];
        },
    ) {
        return await this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.delete(id);
    }
}
