import { Module } from '@nestjs/common';
import { JwtModule } from '@nestjs/jwt';
import { MongooseModule } from '@nestjs/mongoose';
import JwtConfigService from 'src/core/jwt/jwt-config.service';
import JwtHelper from 'src/core/jwt/jwt.helper';
import { DoSpacesServicerovider } from 'src/modules/SpacesModule/SpacesService';
import { DoSpacesService } from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import { UsersSchema } from '../users/schema/users.schema';
import { SolutionsSchema } from '../solutions/schema/solutions.schema';
import { PortfolioSchema } from './schema/portfolio.schema';
import { PortfolioController } from './portfolio.controller';
import { PortfolioService } from './portfolio.service';
import { ServicesSchema } from '../services/schema/services.schema';

@Module({
  imports: [
    JwtModule.registerAsync({
      useClass: JwtConfigService,
    }),
    MongooseModule.forFeature([
      { name: 'Users', schema: UsersSchema },
      { name: 'portfolios', schema: PortfolioSchema },
      { name: 'solutions', schema: SolutionsSchema },
      { name: 'services', schema: ServicesSchema },
    ]),
  ],
  controllers: [PortfolioController],
  providers: [
    PortfolioService,
    JwtHelper,
    DoSpacesService,
    DoSpacesServicerovider,
  ],
})
export class PortfolioModule {}
