import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    Query,
    UploadedFiles,
    UseGuards,
    UseInterceptors,
} from '@nestjs/common';
import { FileFieldsInterceptor } from '@nestjs/platform-express';
import { AdminAuthGuard } from 'src/core/guards/admin-auth.guard';
import { UploadedMulterFileI } from 'src/modules/SpacesModule/SpacesService';
import { Constants } from 'src/utils/constants';
import { CreateServicesDto } from './dto/create-services.dto';
import { UpdateServicesDto } from './dto/update-services.dto';
import { ServicesService } from './services.service';

@Controller({ path: 'services', version: Constants.API_VERSION_1 })
export class ServicesController {
    constructor(private readonly service: ServicesService) { }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        { name: 'image', maxCount: 1 },
        { name: 'icon', maxCount: 1 }
    ]))
    async create(
        @Body() dto: CreateServicesDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
            icon?: UploadedMulterFileI;
        }
    ) {
        return await this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    async findAll(
        @Query('page') pageParam?: string,
        @Query('limit') limitParam?: string,
    ) {
        return await this.service.findAll(pageParam, limitParam);
    }


    @Get(':id')
    @UseGuards(AdminAuthGuard)
    async findOne(@Param('id') id: string) {
        return await this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        { name: 'image', maxCount: 1 },
        { name: 'icon', maxCount: 1 }
    ]))
    async update(
        @Param('id') id: string,
        @Body() dto: UpdateServicesDto,
        @UploadedFiles()
        files: {
            image?: UploadedMulterFileI;
            icon?: UploadedMulterFileI;
        }
    ) {
        return await this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.delete(id);
    }
}
