import mongoose, { Model, Types } from 'mongoose';
import { CreateSocialLinksDto } from './dto/create-social-links.dto';
import { UpdateSocialLinksDto } from './dto/update-social-links.dto';
import { SocialLinks } from './schema/social-links.schema';

export class SocialLinksRepository<SocialLinksDocument extends SocialLinks> {
    constructor(private readonly model: Model<SocialLinksDocument>) { }

    async createEntity(data: CreateSocialLinksDto): Promise<SocialLinks> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<SocialLinks | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async findOneEntityBySlug(urlSlug: string): Promise<SocialLinks | null> {
        try {
            return await this.model.findOne({ urlSlug: urlSlug, isDeleted: false });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, data: UpdateSocialLinksDto): Promise<SocialLinks | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<SocialLinks[]> {
        return await this.model.find({ isDeleted: false });
    }
}