import mongoose, { Model, Types } from 'mongoose';
import { Services } from '../services/schema/services.schema';
import { CreateSolutionsServicesDto } from './dto/create-solutions-services.dto';
import { UpdateSolutionsServicesDto } from './dto/update-solutions-services.dto';
import { SolutionsServices } from './schema/solutions-services.schema';

export class SolutionsServicesRepository<SolutionsServicesDocument extends SolutionsServices> {
    constructor(private readonly model: Model<SolutionsServicesDocument>) { }

    async createEntity(data: CreateSolutionsServicesDto): Promise<SolutionsServices> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findOneEntity(id: string): Promise<SolutionsServices | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }

        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateSolutionsServicesDto): Promise<SolutionsServices | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findAll(): Promise<SolutionsServices[]> {
        return await this.model.find({ isDeleted: false });
    }

    async paginate(page: number, limit: number) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({ isDeleted: false });
        const pageCount = Math.ceil(total / limit);

        const data = await this.model
            .find({ isDeleted: false })
            .skip(skip)
            .limit(limit);

        return {
            data: data,
            pageCount: pageCount
        };
    }

    async findByFilterQuery(query: any): Promise<SolutionsServices[] | null> {
        return await this.model.find({ ...query, isDeleted: false }).lean();
    }

    async createEntities(data: CreateSolutionsServicesDto[]): Promise<SolutionsServices[]> {
        try {
            const createdEntities = await this.model.insertMany(
                data.map((item) => ({ ...item, _id: new Types.ObjectId() }))
            );

            return createdEntities;
        } catch (err) {
            console.log(err);
        }
    }

    async bulkDelete(service: Services) {
        await this.model.deleteMany({ service: service });
    }
}