import mongoose, { Model, Types } from "mongoose";
import { CreateTemporaryPasswordDto } from "./dto/create-temporary-password.dto";
import { UpdateTemporaryPasswordDto } from "./dto/update-temporary-password.dto";
import { TemporaryPassword } from "./schema/temporary-password.schema";

export class TemporaryPasswordRepository<TemporaryPasswordDocument extends TemporaryPassword> {
    constructor(private readonly model: Model<TemporaryPasswordDocument>) { }

    async createEntity(data: CreateTemporaryPasswordDto): Promise<TemporaryPasswordDocument> {
        const createdEntity = new this.model({
            ...data,
            _id: new Types.ObjectId()
        });
        return await createdEntity.save();
    }

    async findAll(): Promise<TemporaryPassword[]> {
        return await this.model.find({ isDeleted: false });
    }

    async findOneEntity(id: string): Promise<TemporaryPassword | null> {
        if (!mongoose.Types.ObjectId.isValid(id)) {
            return null;
        }
        return await this.model.findOne({ _id: id, isDeleted: false });
    }

    async updateEntity(id: string, data: UpdateTemporaryPasswordDto): Promise<TemporaryPassword | null> {
        return await this.model.findByIdAndUpdate(id, data, { new: true });
    }

    async deleteEntity(id: string): Promise<boolean> {
        const data = await this.model.findByIdAndUpdate(
            id,
            { isDeleted: true },
            { new: true }
        );
        if (data) return true;
        return false;
    }

    async findByFilterQuery(query: any): Promise<TemporaryPassword[] | null> {
        return await this.model.find({ ...query, isDeleted: false })
    }

    async paginate(page: number, limit: number) {
        const skip = (page - 1) * limit;
        const total = await this.model.countDocuments({});
        const totalPages = Math.ceil(total / limit);

        const data = await this.model
            .find({ isDeleted: false })
            .skip(skip)
            .limit(limit);

        return {
            data,
            page,
            limit,
            total,
            totalPages
        };
    }
}