import { Body, Controller, HttpCode, HttpStatus, Post, Req, UseGuards } from '@nestjs/common';
// import {AuthGuard} from 'src/core/guards/auth.guard';
import { Constants } from '../../utils/constants';
import { AuthService } from './auth.service';
import { LoginAuthDto } from './dto/login-auth.dto';
import { RegisterAuthDto } from './dto/register-auth.dto';
import { AuthGuard } from 'src/core/guards/auth.guard';
import { ResetPasswordRequestDto } from './dto/reset-password.dto';
import { CheckVerifyHashPasswordDto } from './dto/check-verify-hash-password-token';
import { UpdatePasswordUsingVerifyHashPasswordTokenDto } from './dto/update-password-using-verify-hash-password-token';

@Controller({
    path: 'auth',
    version: Constants.API_VERSION_1
})
export class AuthController {

    constructor(private readonly authService: AuthService) {}

    @Post('/register')
    async register(@Body() dto: RegisterAuthDto) {
        return await this.authService.register(dto);
    }

    @Post('/login')
    async login(@Body() dto: LoginAuthDto) {
        return await this.authService.login(dto);
    }

    @Post('/validate-token')
    async verifyToken(@Req() req: any) {
        return await this.authService.validateRequest(req);
    }

    @Post('/forgot-password')
    async forgotPassword(@Body() dto: ResetPasswordRequestDto) {
        return await this.authService.forgotPassword(dto);
    }

    @Post('/verify-hash-token')
    async verifyHashToken(
        @Body() dto: CheckVerifyHashPasswordDto
    ) {
        return await this.authService.verifyHashPasswordTokenRequest(dto);
    }

    @Post('/hash-token/update-password')
    async updatePasswordUsingHashToken(
        @Body() dto: UpdatePasswordUsingVerifyHashPasswordTokenDto
    ) {
        return await this.authService.updatePasswordUsingTokenRequest(dto);
    }
}
