import { MailerService } from '@nestjs-modules/mailer';
import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { Constants } from '../../utils/constants';
import { CreateMailSenderDto } from './dto/create-mail-sender.dto';
import { ResetPasswordMailDto } from './dto/create-reset-password-mail.dto';
import { CreateBecomeFranchiseMailSenderDto } from './dto/create-become-franchise-mail.dto';

@Injectable()
export class MailSenderService {
    constructor(
        private readonly mailerService: MailerService,
    ) {
    }

    async agentAccountCreateMailSender(dto: CreateMailSenderDto) {
        const { to, from, subject, template, username, email, password,
            privacyPolicyPage, termsOfUsePage, loginPage, companyEmail, companyAddress
        } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to,
                bcc: ['neutrixtester@gmail.com'],
                from: from,
                subject: subject,
                template: template,
                context: {
                    username: username,
                    fullName: username,
                    email: email,
                    password: password,
                    privacyPolicyPage: privacyPolicyPage,
                    termsOfUsePage: termsOfUsePage,
                    loginPage: loginPage,
                    companyEmail: companyEmail,
                    companyAddress: companyAddress,
                }
            })
            .catch((err) => {
                console.log("Error: ", err);
                // throw new HttpException(
                //     Constants.GENERIC_ERROR,
                //     HttpStatus.INTERNAL_SERVER_ERROR
                // );
            });
        console.log({
            message: 'Mail sent to: ' + to
        });
        return {
            message: 'Mail sent to: ' + to
        };
    }

    async sendPasswordResetRequestMail(dto: ResetPasswordMailDto) {
        const { to, from, subject, username, token, email, companyEmail, companyAddress } = dto;

        const result = await this.mailerService
            .sendMail({
                to: to,
                bcc: ['neutrixtester@gmail.com'],
                from: from,
                subject: subject,
                template: './templates/dynamic_customer_forgot_password_email',
                context: {
                    username: username,
                    token: token,
                    passwordResetURL: process.env.PASSWORD_RESET_PAGE,
                    privacyPolicyPage: process.env.PRIVACY_POLICY_PAGE,
                    termsOfUsePage: process.env.TERMS_OF_USE_PAGE,
                    companyEmail: companyEmail,
                    companyAddress: companyAddress,
                }
            })
            .catch((err) => {
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.INTERNAL_SERVER_ERROR
                );
            });
        return {
            message: 'Mail sent to: ' + to
        };
    }

    async becomeFranchiseMailSender(dto: CreateBecomeFranchiseMailSenderDto) {
        const { to, from, subject, template, privacyPolicyPage, termsAndConditionPage, companyEmail, companyAddress, customerName } = dto;
        const result = await this.mailerService
            .sendMail({
                to: to,
                bcc: ['neutrixtester@gmail.com'],
                from: from,
                subject: subject,
                template: template,
                context: {
                    privacyPolicyPage: privacyPolicyPage,
                    termsAndConditionPage: termsAndConditionPage,
                    companyEmail: companyEmail,
                    companyAddress: companyAddress,
                    customerName: customerName
                }
            })
            .catch((err) => {
                console.log("Error: ", err);
            });
        console.log({
            message: 'Mail sent to: ' + to
        });
        return {
            message: 'Mail sent to: ' + to
        };
    }
}
